@@ -31,7 +31,7 @@
 #define HIDE_REASON_OTHER_FRAGMENT  4
 #define HIDE_REASON_HYDROGEN        8
 #define HIDE_REASON_QPEAK          16 
-
+#define HIDE_REASON_BELO           32
 /*! \brief ChGL is the QGLWidget of ShelXle
  */
 class ChGL : public QGLWidget{
@@ -87,7 +87,8 @@ public:
 	    *enviNoQ,//!< QAction ENVI only for real atoms
 	    *enviCova,//!< QAction ENVI only for covalent contacts
 	    *wireButt,//!< QAction show atoms while rotation in wire mode
-	    *invSelection;//!< QAction invert selection
+	    *invSelection,//!< QAction invert selection
+            *hideBeLo;//!< hide/show  BEDE and LONE objects
     QToolButton *enviButt;//!< Button to clear the envi -ronment.
     QList<V3>enviPositions;//!<List of atom postions of an envi-ronment.
     QList<int>enviKat;//!< List of categorys of contacts in an envi-ronment.
@@ -202,6 +203,7 @@ public slots:
     void setViewAngle(double ang);
     void showHidden();
     void showMatrix();
+    void toogleWithSymmetry(bool b);
     void zoomOut();
     void unsetTube(bool b){
       //!sets tube mode to not b
@@ -221,6 +223,7 @@ public slots:
     void addRIGU();
     void addCHIV();
     void addANIS();
+    void wuff();
 
 protected:
    void initializeGL();
@@ -254,6 +257,7 @@ private:
 	int hideReason; 
         double qcutoff,pickradius;
 	int frid;
+        int withsymm;
         QPoint lastPos;
     QStringList resis();
 };
