@@ -583,7 +583,7 @@ void CodeEditor::keyPressEvent(QKeyEvent *e){
   if (e->key() == Qt::Key_F1) {
     QTextCursor tc = textCursor();
     tc.select(QTextCursor::WordUnderCursor);
-    QString txt = tc.selectedText().toUpper();
+    QString txt = tc.selectedText().toUpper().split("_").first();
     if ( Window::isacommand(txt) >= 0 ) {
       QUrl help_url = QString("http://shelx.uni-goettingen.de/shelxl_html.php#%1").arg(txt);
       QDesktopServices::openUrl(help_url);
