@@ -75,6 +75,7 @@ DSREditWindow::DSREditWindow(Molecule *mol, DSRMol *header,
   abort_renameButton = new QPushButton("Abort");
   //abort_renameButton->setStyleSheet("QPushButton{background: rgb(255, 180, 180);}");
   buttonlayout = new QGridLayout;
+  infoLabel = new QLabel;
   //    buttongrid          row column spanrow spancolumn:
   buttonlayout->addWidget(addButton,     0, 0);
   buttonlayout->addWidget(updateButton,  0, 1);
@@ -82,8 +83,10 @@ DSREditWindow::DSREditWindow(Molecule *mol, DSRMol *header,
   buttonlayout->addWidget(mailButton,    1, 0);
   buttonlayout->addWidget(clearButton,   1, 1);
   buttonlayout->addWidget(renameButton,  1, 2);
+  buttonlayout->addWidget(infoLabel,     2, 0, 2, 3);
+  //infoLabel->setStyleSheet("border: 1px solid lightgrey");
   addButton->setDisabled(true);
-  infoLabel = new QLabel;
+
     //    maingrid          row column spanrow spancolumn:
   maingrid->setRowStretch(1, 2);
   maingrid->setRowStretch(3, 2);
@@ -93,7 +96,7 @@ DSREditWindow::DSREditWindow(Molecule *mol, DSRMol *header,
   maingrid->setColumnStretch(2, 0);
   maingrid->setColumnStretch(3, 0);
   maingrid->setColumnStretch(4, 2);
-  maingrid->addWidget(myedgl,      0, 4, 4, 4);
+  maingrid->addWidget(myedgl,      0, 4, 4, 3);
   maingrid->addWidget(cellabel,    0, 0, 1, 1);
   maingrid->addLayout(cellLayout,  0, 1, 1, 3);
   maingrid->addWidget(namelabel,   1, 0, 1, 1);
@@ -105,9 +108,8 @@ DSREditWindow::DSREditWindow(Molecule *mol, DSRMol *header,
   maingrid->addWidget(atomsEdit,   3, 1, 1, 3);
   maingrid->addWidget(restrlabel,  4, 0, 2, 1);
   maingrid->addWidget(restrEdit,   4, 1, 2, 3);
-  maingrid->addLayout(buttonlayout,4, 4, 2, 1, Qt::AlignTop);
-  maingrid->addWidget(infoLabel,   5, 4, 2, 1, Qt::AlignTop);
-  //infoLabel->setStyleSheet("border: 1px solid");
+  maingrid->addLayout(buttonlayout,4, 4, 2, 3, Qt::AlignTop);
+
   addButton->setToolTip("Add this fragment to the database.\n"
                         "Fragments from the database supplied by DSR will\n"
                         "always be stored as a new fragment in the user database.");
@@ -210,10 +212,6 @@ void DSREditWindow::connectSignalsAndSlots()
           this, SLOT(setInfoLabel(QString)));
   connect(addButton, SIGNAL(clicked()),
           this, SLOT(addFragment()));
-  connect(addButton, SIGNAL(clicked()),
-          this, SLOT(close()));
-  connect(addButton, SIGNAL(clicked()),
-          this, SLOT(updateFraglist()));
   connect(deleteButton, SIGNAL(clicked()),
           this, SLOT(deleteCurrentFragment()));
   connect(deleteButton, SIGNAL(clicked()),
@@ -222,10 +220,6 @@ void DSREditWindow::connectSignalsAndSlots()
           this, SLOT(close()));             // thus it is closed.
   connect(updateButton, SIGNAL(clicked()),
           this, SLOT(updateFragment()));
-  connect(updateButton, SIGNAL(clicked()),
-          this, SLOT(updateFraglist()));
-  connect(updateButton, SIGNAL(clicked()),  // the information in this window gets useless,
-          this, SLOT(close()));             // thus it is closed.
   connect(use_selected, SIGNAL(clicked()),
           this, SLOT(setSelectedAtoms()));
   connect(mailButton, SIGNAL(clicked()),
@@ -362,8 +356,8 @@ void DSREditWindow::abortRenameMode(){
           this, SLOT(setAtoms()));
   connect(restrEdit, SIGNAL(textChanged()),
           this, SLOT(setRestraints()));
-  atomsEdit->setText(oldatoms->toAscii());
-  restrEdit->setText(oldrestraints->toAscii());
+  atomsEdit->setText(oldatoms->toLatin1());
+  restrEdit->setText(oldrestraints->toLatin1());
   myedgl->display_fragment(*m_header);
 }
 
@@ -398,11 +392,21 @@ void DSREditWindow::addFragment() {
   //! combines new fragment and write db to the harddisk
   QStringList origdb;
   QStringList newdb;
+  if (!validateCell()) {
+      emit line_error(QString(tr("<font color=red><b>No valid unit cell!</font>")));
+      return;
+  }
+  if (nameEdit->text().isEmpty()) {
+      emit line_error(QString(tr("<font color=red><b>Please give the fragment a name.</font>")));
+      return;
+  }
   origdb = readFragmentDB();
   newdb = combineDataToNewFragment();
   origdb.append(newdb);
   userdb = true;
   writeFragmentDB(origdb);
+  this->updateFraglist();
+  this->close();
 }
 
 void DSREditWindow::updateFragment() {
@@ -411,12 +415,22 @@ void DSREditWindow::updateFragment() {
   QStringList newFragment;
   QString delfrag; // I will delete this later
   delfrag = m_nametag;
+  if (!validateCell()) {
+      emit line_error(QString(tr("<font color=red><b>No valid unit cell!</font>")));
+      return;
+  }
+  if (nameEdit->text().isEmpty()) {
+      emit line_error(QString(tr("<font color=red><b>Please give the fragment a name.</font>")));
+      return;
+  }
   origdb = readFragmentDB();
   newFragment = combineDataToNewFragment();
   origdb.append(newFragment);
   userdb = true;
   writeFragmentDB(origdb);
   deleteFragment(delfrag);
+  this->updateFraglist();
+  this->close();
 }
 
 QStringList DSREditWindow::combineDataToNewFragment(){
@@ -622,7 +636,7 @@ void DSREditWindow::renameRestraints(QStringList new_atnames, int cursopos){
       foreach (QString newatom, new_atnames) {
         for(int i = 0; i < rline_list.length(); i++) {
           if (rline_list.at(i).toUpper() == previous_atoms->at(num).toUpper()) {
-            rline_list[i] = newatom.toUpper().toAscii();
+            rline_list[i] = newatom.toUpper().toLatin1();
           }
         }
         num++;
@@ -660,15 +674,23 @@ void DSREditWindow::renameAtoms(){
       return;
     }
     line_split = line.split(" ", QString::SkipEmptyParts);
-    line_split[0] = line_split.at(0).left(4);
     if (line_split.length() > 0){
-      new_atnames.append(line_split.at(0)); // collect new atom names after after a character was changed
+      line_split[0] = line_split.at(0).left(4);
+      new_atnames.append(line_split.at(0).toUpper()); // collect new atom names after after a character was changed
+    } else {  // This is to make sure there is no empty line. An empty line will cause the rename mode to abort.
+        this->atomsEdit->undo();
+        this->abortRenameMode();
+        error = QString(tr("<font color=red><b>Do not delete atoms in rename mode!</font>"));
+        emit line_error(error);
+        return;
     }
     num++;
     if (new_atnames.count(line_split.at(0)) >= 2) {
-      // warn user about duplicates and do not rename restraints
-      error = QString(tr("<font color=red><b>Douplicate atom found! <br>Please make them unique.</font>"));
+      // warn user about duplicates and do not rename atom:
+      error = QString(tr("<font color=red><b>Attempt to create duplicate atom \"%1\" detected. "
+                         "<br>Please make them unique.</font>").arg(line_split.at(0)));
       emit line_error(error);
+      atomsEdit->undo();           // In this case, undo last action. Makes duplicates impossible
       connect(atomsEdit, SIGNAL(textChanged()),
               this, SLOT(renameAtoms()));
       return;
@@ -717,24 +739,18 @@ void DSREditWindow::setAtoms(){
     line_split = checkAtomLine(line_split, num+1);
     myAtoms.append(line_split);
     if (line_split.length() > 0){
-      atnames.append(line_split.at(0));
-      if (atnames.count(line_split.at(0)) >= 2) {
-        error = QString(tr("<font color=red><b>Douplicate atom found! Please make them unique.</font>"));
+      atnames.append(line_split.at(0).toUpper());
+      if (atnames.count(line_split.at(0).toUpper()) >= 2) {
+        error = QString(tr("<font color=red><b>Duplicate atom \"%1\" found! Please make them unique.</font>").arg(line_split.at(0)));
+        // Can not do undo(), because it would prevent adding duplicate names with "add selected atoms"
+        // and this has to be possible because of residues:
+        //atomsEdit->undo();
         emit line_error(error);
         return;
       }
     }
     num++;
   }
-  if (!badLine) {
-    emit line_error("");
-    addButton->setEnabled(true);
-    updateButton->setEnabled(true);
-  } else {
-    updateButton->setDisabled(true);
-    addButton->setDisabled(true);
-    return;
-  }
   if (myAtoms.size() <= 1 && myAtoms[0].isEmpty()) {
     addButton->setDisabled(true);
     updateButton->setDisabled(true);
@@ -745,6 +761,15 @@ void DSREditWindow::setAtoms(){
     addButton->setEnabled(true);
     updateButton->setEnabled(true);
   }
+  if (!badLine) {
+    emit line_error("");
+    addButton->setEnabled(true);
+    updateButton->setEnabled(true);
+  } else {
+    updateButton->setDisabled(true);
+    addButton->setDisabled(true);
+    return;
+  }
 }
 
 void DSREditWindow::setSelectedAtoms() {
@@ -758,7 +783,7 @@ void DSREditWindow::setSelectedAtoms() {
   for (int i = 0; i < numselect; i++) {
     line.clear();
     atname.clear();
-    atname = m_mol->selectedatoms.at(i).orginalLine.split(' ')[0];
+    atname = m_mol->selectedatoms.at(i).Label.split('_')[0];
     if (i == 0) {
       firstatom = atname;
     }
