@@ -292,6 +292,7 @@ void DSRGlWindow::display_fragment(DSRMol frag)
     return;
   }
   foreach (QStringList atom, frag.atoms) {
+    if (atom.length() < 4)  continue;  // Do not crash on empty string
     newAtom.Label = atom.at(0);
     newAtom.an = abs(atom.at(1).toInt())-1;
     newAtom.pos.x = atom.at(2).toDouble();
@@ -452,29 +453,22 @@ void DSRGlWindow::tryfit(){
   b3=Normalize(b1%b2);
   b2=b3%b1;
   Matrix bmat=transponse(Matrix(b1,b2,b3));
-//  Matrix bmat=Matrix(b1,b2,b3);
- /* printf(" %9.4f%9.4f%9.4f\n %9.4f%9.4f%9.4f\n %9.4f%9.4f%9.4f\n %f %f %f %f\n",
-      a1.x,a1.y,a1.z, 
-      a2.x,a2.y,a2.z, 
-      a3.x,a3.y,a3.z,
-      Norm(a1),Norm(a2),Norm(a3),a1*(a2%a3)
-      );
-  printf(" %9.4f%9.4f%9.4f\n %9.4f%9.4f%9.4f\n %9.4f%9.4f%9.4f\n %f %f %f %f\n",
-      b1.x,b1.y,b1.z, 
-      b2.x,b2.y,b2.z, 
-      b3.x,b3.y,b3.z,
-      Norm(b1),Norm(b2),Norm(b3),b1*(b2%b3)
-      );
-//  */
-   if ((a1*(a2%a3)<0.9)||(b1*(b2%b3)<0.9)) {updateGL();return;}//linear dependence id determinant is 0
-  for (int i=0; i<m_molecule->asymm.size(); i++){
-    fita.append( m_molecule->asymm[i]);
+  if ( (a1*(a2%a3)<0.9) || (b1*(b2%b3)<0.9) ) {  //linear dependence id determinant is 0
+    updateGL();
+    return;
+  }
+  // m_molecule->showatoms was m_molecule->asymm before, but showatoms is needed for disorder
+  // around special positions:
+  for (int i=0; i<m_molecule->showatoms.size(); i++) {
+    fita.append( m_molecule->showatoms[i]);
     fita.last().pos+=-1.0*(m_molecule->selectedatoms.at(0).pos); 
     fita.last().pos=fita.last().pos*amat;
     fita.last().pos=fita.last().pos*bmat;
     fita.last().pos+=selFragAt.at(0).pos;
     fita.last().part=1;
-    if (Norm (fita.last().pos)>9.0) fita.removeLast();//3.0 Angstroem cut of (3*3=9) 
+    if (Norm (fita.last().pos) > 12) {  // 4 Angstroem cut of (3*4=12)
+      fita.removeLast();
+    }
   }  
   fitabonds=mole.connecting(fita,true);
   updateGL();
@@ -482,8 +476,8 @@ void DSRGlWindow::tryfit(){
   for (int i=0; i<xd.size(); i++){
     int imin=0;
     double dmin=10.0;
-    for (int j=0; j<m_molecule->asymm.size(); j++){
-      V3 ort=m_molecule->asymm.at(j).pos;
+    for (int j=0; j<m_molecule->showatoms.size(); j++){
+      V3 ort=m_molecule->showatoms.at(j).pos;
       ort+=-1.0*(m_molecule->selectedatoms.at(0).pos); 
       ort=ort*amat;
       ort=ort*bmat;
@@ -493,6 +487,7 @@ void DSRGlWindow::tryfit(){
       if (d<dmin) imin=j;
       dmin=(d<dmin)?d:dmin;
     }
-    printf("%-8s <==> %-8s %f\n",xd.at(i).Label.toStdString().c_str(),m_molecule->asymm.at(imin).Label.toStdString().c_str(),sqrt(dmin));
+    printf("%-8s <==> %-8s %f\n", xd.at(i).Label.toStdString().c_str(),
+           m_molecule->showatoms.at(imin).Label.toStdString().c_str(),sqrt(dmin));
   }
 }
