@@ -58,10 +58,10 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   m_shelxle = parent;
   m_molecule = mole;
   m_shelxlPath = shelxlPath;
+  // Qt::WindowStaysOnTopHint makes no sense here, because of the update info window
   setWindowFlags(Qt::Window);
   setWindowTitle(QString(tr("DSR GUI")));
-  resFileName = m_shelxle->dirName;
-  if (mysystem == QString("win")){
+  if (mysystem == QString("win")) {
     dsrpath = getDSRDir()+"/dsr.bat";
     dsr_db_path = getDSRdbDir();
   } else if (mysystem == QString("unix")){
@@ -74,6 +74,8 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   runext = false;
   invert = false;
   rigid = false;
+  cf3 = false;
+  splitmode = false;
   fragmentsList = new QVector<QStringList>;
   fragmentNameTag.clear();
   header = new DSRMol;
@@ -82,6 +84,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   chooserLayout = new QGridLayout;
   searchLayout = new QHBoxLayout;
   partLayout = new QHBoxLayout;
+  fvarLayout = new QHBoxLayout;
   occLayout = new QHBoxLayout;
   resclassLayout = new QHBoxLayout;
   optionsLayout1 = new QVBoxLayout;
@@ -106,11 +109,13 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   dfixBox = new QCheckBox(tr("Calculate DFIX"));
   rigidBox = new QCheckBox(tr("Rigid Group (no restraints)"));
   replaceModeBox = new QCheckBox(tr("Replace Target"));
+  splitModeBox = new QCheckBox(tr("Split Target"));
   searchLabel = new QLabel(tr("Search:"));
   SearchInp = new QLineEdit;//(tr("Search a fragment here"));
-  partLabel = new QLabel(tr("PART:"));
-  occLabel = new QLabel(tr("FVAR+Occupancy:"));
-  classLabel = new QLabel(tr("Residue Class:"));
+  partLabel = new QLabel(tr("PART"));
+  fvarLabel = new QLabel(tr("Free Variable"));
+  occLabel = new QLabel(tr("Occupancy"));
+  classLabel = new QLabel(tr("Residue Class"));
   usermanualLabel = new QLabel(tr("<a href=\"http://www.xs3-data.uni-freiburg.de/data/DSR-manual.pdf\"> DSR User Manual </a>"));
   usermanualLabel->setOpenExternalLinks(true);
   resnumbertext = new QString(tr("A residue number will be\nchosen automatically."));
@@ -120,15 +125,19 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   info = new QTextBrowser;
   info->hide();
   info->setMinimumWidth(235);
-  info->setMaximumWidth(235);
+  //info->setMaximumWidth(235);
   fragmentTableView = new QTableView;
   occEdit = new QLineEdit;
   partspinner = new QSpinBox;
+  fvarspinner = new QSpinBox;
   resiclassEdit = new QLineEdit;
   // layout for the interactions
   optionboxes->addWidget(groupBox1);
+  optionboxes->addStretch();
   optionboxes->addWidget(groupBox2);
+  optionboxes->addStretch();
   optionboxes->addWidget(residueOptionsBox);
+  optionboxes->addStretch();
   optionboxes->addLayout(buttonLayout);
   buttonLayout->setSizeConstraint(QLayout::SetMaximumSize);
   // The search field:
@@ -157,26 +166,38 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   mainVLayout->addLayout(chooserLayout, 3);
   mainVLayout->addLayout(editLayout, 2);
   mainVLayout->addLayout(optionboxes, 0);
-  prepareOuttext();
   editLayout->addWidget(outtext);
   editLayout->addWidget(info);
+  editLayout->setStretchFactor(outtext, 2);
+  editLayout->setStretchFactor(info, 1);
+  outtext->setReadOnly(true);
+  QFont font("Courier");
+  font.setStyleHint(QFont::TypeWriter);
+  outtext->setFont(font);
   outtext->setMinimumHeight(170);
   // Layouts for optionbox1
-  partLayout->addStretch();
-  partLayout->addWidget(partLabel);
   partLayout->addWidget(partspinner);
+  partLayout->addWidget(partLabel);
+  partLayout->addStretch();
   partspinner->setRange(-99, 99);
   partspinner->setValue(0);
-  occLayout->addWidget(occLabel);
+  fvarLayout->addWidget(fvarspinner);
+  fvarLayout->addWidget(fvarLabel);
+  fvarLayout->addStretch();
+  fvarspinner->setRange(-99, 99);
+  fvarspinner->setValue(1);
   occLayout->addWidget(occEdit);
-  occLabel->setAlignment(Qt::AlignRight);
-  occEdit->setMaximumWidth(getCharWidth(8));
-  occEdit->setMinimumWidth(getCharWidth(6));
+  occLayout->addWidget(occLabel);
+  occEdit->setValidator(new QDoubleValidator(0, 99, 5, occEdit));
+  occEdit->setMaximumWidth(getCharWidth(5));
+  occEdit->setMinimumWidth(getCharWidth(5));
   // box1
   optionsLayout1->addLayout(partLayout);
+  optionsLayout1->addLayout(fvarLayout);
   optionsLayout1->addLayout(occLayout);
   optionsLayout1->addWidget(replaceModeBox);
-  replaceModeBox->setLayoutDirection(Qt::RightToLeft);
+  optionsLayout1->addWidget(splitModeBox);
+  splitModeBox->hide();
   optionsLayout1->addStretch();
   groupBox1->setLayout(optionsLayout1);
   // box2
@@ -187,9 +208,8 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   optionsLayout2->addStretch();
   groupBox2->setLayout(optionsLayout2);
   // box3
-  resclassLayout->addWidget(classLabel);
   resclassLayout->addWidget(resiclassEdit);
-  classLabel->setAlignment(Qt::AlignRight);
+  resclassLayout->addWidget(classLabel);
   resiclassEdit->setMaximumWidth(getCharWidth(8));
   resiclassEdit->setMinimumWidth(getCharWidth(6));
   optionsLayout3->addLayout(resclassLayout);
@@ -221,17 +241,17 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   getVersionFromServer();
   // Signal slot connections:
   connect_signals_and_slots();
-  //this->setMinimumSize(815, 615);
-  //this->setMaximumSize(950, 999);
-  this->move(220, 20);
+  occEdit->setText("1");
   checkForDSRexecutable(splash);
-  this->show();
   splash->finish(this);
   // call last, because keyboard focus is reated to tab order,
   // which is based on the order the widgets are created:
   SearchInp->setFocus();
   // Has to be here, otherwise fragmentTableView is not initialized:
   QItemSelectionModel *sm = fragmentTableView->selectionModel();
+  this->move(m_shelxle->width(), 30);  // prevents flickering
+  this->show(); // has to be directly before move(), otherwise the window has wrong position
+  this->move(m_shelxle->width()-this->width()-30, 30);
   if (!(sm == 0x0)){  // prevents error about missing connection if DSR is not present
     connect(sm, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
         this, SLOT(setFragName(QModelIndex)), Qt::UniqueConnection);
@@ -276,11 +296,15 @@ void DSRGui::connect_signals_and_slots() {
     connect(SearchInp, SIGNAL(textChanged(QString)),
             this, SLOT(searchFragment(QString)));
     connect(occEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(setFvarOcc(QString)));
+            this, SLOT(setFvarOcc(void)));
+    connect(fvarspinner, SIGNAL(valueChanged(QString)),
+            this, SLOT(setFvarOcc(void)));
     connect(resiclassEdit, SIGNAL(textChanged(QString)),
             this, SLOT(setResiClass(QString)));
     connect(residueOptionsBox, SIGNAL(toggled(bool)),
             this, SLOT(combineOptionstext()));
+    connect(splitModeBox, SIGNAL(toggled(bool)),
+            this, SLOT(combineOptionstext()));
     connect(partspinner, SIGNAL(valueChanged(int)),
             this, SLOT(setPART(int)));
     connect(exportFragButton, SIGNAL(clicked(bool)),
@@ -316,14 +340,12 @@ void DSRGui::connect_signals_and_slots() {
             this, SLOT(isDSRUpToDate(QNetworkReply*)));
 }
 
-QSize DSRGui::minimumSizeHint() const
-{
-  return QSize(800, 800);
+QSize DSRGui::minimumSizeHint() const {
+  return QSize(700, 700);
 }
 
-QSize DSRGui::sizeHint() const
-{
-  return QSize(800, 930);
+QSize DSRGui::sizeHint() const {
+  return QSize(700, 780);
 }
 
 void DSRGui::getVersionFromServer() {
@@ -336,7 +358,7 @@ void DSRGui::getVersionFromServer() {
   }
 
 
-void DSRGui::isDSRUpToDate(QNetworkReply* reply){
+void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   /*
    *! Displays a warning if the current DSR version is too old.
   */
@@ -375,7 +397,7 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply){
 }
 
 
-void DSRGui::updateTarget(){
+void DSRGui::updateTarget() {
   //! updates the target atoms list
   target_atoms = getSelectedAtomsList();
   combineOptionstext();
@@ -395,6 +417,9 @@ QString DSRGui::loadFavoriteFragment() {
   dsr_settings.beginGroup("LastFragment");
   QString last = dsr_settings.value("last").toString();
   dsr_settings.endGroup();
+  if (last == QString("cf6")) {
+    splitModeBox->show();
+  }
   return last;
 }
 
@@ -427,7 +452,7 @@ QStringList DSRGui::which(QString programName) {
   return foundInPath;
 }
 
-void DSRGui::checkForDSRexecutable(QSplashScreen *splash){
+void DSRGui::checkForDSRexecutable(QSplashScreen *splash) {
   //! list fragments only if the path of dsr installation is found:
   if (QFile::exists(dsrpath)) {
     listDSRdbFragments("None");
@@ -448,9 +473,10 @@ void DSRGui::setToolTips() {
                              "bind each other but to PART 0. Negative PARTs only bind themselves."));
   replaceModeBox->setToolTip(tr("Toggle replacement of target atoms and all atoms of "
                              "PART 0 \nin 1.3A distance around the fitted fragment atoms."));
-  occEdit->setToolTip(tr("Free variable and occupancy of the fragment "
-                         "\ncombined according SHELXL syntax.\n"
-                         "For example, 21 means second free variable with occupation of 1."));
+  occEdit->setToolTip(tr("The occupancy of the fragment\n"));
+  fvarspinner->setToolTip(tr("The Free Variable for the fragment.\n"
+                             "Free Variable and Occupation will be combined occording to the SHELXL syntax.\n"
+                             "For example, 21.0 means second free variable with occupation of 1."));
   invertFragBox->setToolTip(tr("Invert the fragment coordinates during fit."));
   runExtBox->setToolTip(tr("Write restraints to external file."));
   dfixBox->setToolTip(tr("Calculate DFIX/DANG/FLAT restraints "
@@ -466,13 +492,13 @@ void DSRGui::setToolTips() {
 }
 
 QString DSRGui::textWrap(QString inText, int length = 75) {
-  //! returns a SHELXL compatible wrapped string (string =\n string) in case of over 77 characters
+  //! returns a SHELXL compatible wrapped string (string =\\n string) in case of over 77 characters
   //! line length
   QString firstLine = "";
   QString secondline = "";
   if (inText.length() > length) {
     foreach (QString chunk, inText.split(" ")) {
-      if (firstLine.length()+(chunk+QString(" ")).length() < length) {
+      if ((firstLine.length()+(chunk+QString(" ")).length() < length) && ( secondline.isEmpty() )){
         firstLine.append(chunk+QString(" "));
       } else {
         secondline.append(chunk+QString(" "));
@@ -492,7 +518,7 @@ void DSRGui::resetSelection() {
   info->hide();
 }
 
-void DSRGui::setInfo(QString s){
+void DSRGui::setInfo(QString s) {
   //! shows an info table with bond distances
   if (mygl->selFragAt.size()<1) {
     info->hide();
@@ -503,7 +529,7 @@ void DSRGui::setInfo(QString s){
   }
 }
 
-void DSRGui::runEditWindow(void){
+void DSRGui::runEditWindow(void) {
   //! Starts the edit window in order to edit a fragment
   editwindow = new DSREditWindow(m_molecule, header, dsr_db_path,
                                  fragmentNameTag, *fragmentsList, this);
@@ -516,9 +542,8 @@ void DSRGui::runEditWindow(void){
           this, SLOT(listDSRdbFragments(QString)));
 }
 
-void DSRGui::closeEvent(QCloseEvent *event)
+void DSRGui::closeEvent(QCloseEvent *event) {
 //! close event is emmited during DSRGui closing to reset its pointer
-{
   emit closed();
   (void)event; // prevent compiler warning
 }
@@ -528,6 +553,8 @@ int DSRGui::findFVARlines(QStringList *reslist) {
   //! I restrict the use of this plugin to stuctures with a valid
   //! FVAR, because a missing FVAR makes it all too error prone.
   int fvarline;
+  // I need lastIndexOf() here, because in case of
+  // several FVAR lines indexOf() would fail:
   fvarline = reslist->lastIndexOf(QRegExp("^FVAR.*", Qt::CaseInsensitive));
   if (fvarline > 0) {
     return fvarline;
@@ -555,6 +582,11 @@ int DSRGui::decideDSRInsertLine(QStringList *reslist) {
   int fvarline = findFVARlines(reslist);
   if (fvarline > 0) {
     return fvarline;
+  } else if (m_shelxle->firstAtomLine > 0) {
+    // in this case, no FVAR is present and we put the DSR command line
+    // before the first atom
+    combiDSRline = QString("FVAR 1\n") + combiDSRline; // dummy FVAR is added for DSR
+    return m_shelxle->firstAtomLine - 1;
   } else {
     return 0;
   }
@@ -562,7 +594,7 @@ int DSRGui::decideDSRInsertLine(QStringList *reslist) {
 
 QStringList DSRGui::readResfile() {
   //! read the entire res file into a stringlist
-  QFileInfo fi(resFileName);
+  QFileInfo fi(m_shelxle->dirName);
   QFile file(fi.absoluteFilePath());
   QStringList stringList;
   if (file.open(QFile::ReadOnly | QFile::Text)) {
@@ -649,6 +681,7 @@ bool DSRGui::getFragmentHeader(QString frag) {
   header->residue.clear();
   header->restr.clear();
   header->tag.clear();
+  outtext->clear();
   QString *rawheader = new QString;
   QStringList *headerlist = new QStringList;
   QProcess dsr;
@@ -673,11 +706,16 @@ bool DSRGui::getFragmentHeader(QString frag) {
   }
   headerlist->append(rawheader->split(QRegExp("\n|\r\n|\r")));
   QStringList line;
-  for (int i=0; i<headerlist->size(); i++){
+  for (int i=0; i<headerlist->size(); i++) {
     if (headerlist->at(i).size() == 0){
       continue;
     }
     line.clear();
+    if (headerlist->at(i).trimmed().startsWith("***")) {
+      QString error;
+      error = headerlist->at(i).trimmed();
+      outtext->append("<b>"+error+"</b>");
+    }
     if (headerlist->at(i).trimmed().startsWith("<tag>")) {
       line = headerlist->at(i+1).trimmed().split(" ");
       header->tag = line.join("");
@@ -718,29 +756,12 @@ bool DSRGui::getFragmentHeader(QString frag) {
         header->atoms.append(item.split(" "));
       }
     }
-    if (headerlist->at(i).trimmed().startsWith(tr("Suspicious deviation in atom"))) {
-      outtext->append(headerlist->at(i-1));
-      outtext->append(headerlist->at(i));
-      outtext->append(headerlist->at(i+1));
-      outtext->append(tr("Please check this database entry!"));
-      return true;
-    }
   }
   editButton->setEnabled(true);
   return true;
 }
 
 
-void DSRGui::prepareOuttext() {
-//! prepares the outtext field in order to display infos/warnings
-  outtext->setReadOnly(true);
-  QFont font("Courier");
-  font.setStyleHint(QFont::TypeWriter);
-  outtext->setFont(font);
-  outtext->setMinimumWidth(getCharWidth(70));
-  outtext->setMinimumHeight(55);
-}
-
 int DSRGui::getCharWidth(int numchars) {
   //! returns the width in pixel of numchars times the # character
   QString buchstaben;
@@ -752,27 +773,65 @@ int DSRGui::getCharWidth(int numchars) {
 }
 
 
-void DSRGui::activateFitButton(void){
+void DSRGui::activateFitButton(void) {
     fitDSRButton->setEnabled(true);
     exportFragButton->setEnabled(true);
 }
 
 
-void DSRGui::combineOptionstext(void)
+void DSRGui::combineOptionstext(void) {
 //! combines all options to a single DSR command line
 //! This method gets invoked if optionTextChanged signal is emmitted
-{
-  outtext->clear();
-  //target_atoms = getSelectedAtomsList();
+  if (!outtext->toPlainText().contains("***")) {
+    outtext->clear();
+  } //else {
+    //return;
+  //}
+  QString split = "";
+  // CF3 groups are dummy entries in the DSR database. They get calculated
+  // on ideal positions at the respective carbon atom:
+  if (fragmentNameTag == QString("cf6")) {
+    splitModeBox->show();
+  } else {
+    splitModeBox->hide();
+  }
+  if ( (fragmentNameTag == QString("cf3")) ||
+       (fragmentNameTag == QString("cf6")) ||
+       (fragmentNameTag == QString("cf9")) ) {
+    this->cf3 = true;
+    residueOptionsBox->setChecked(false);
+    rigidBox->setDisabled(true);
+    invertFragBox->setDisabled(true);
+    runExtBox->setDisabled(true);
+    replaceModeBox->setDisabled(true);
+    if (splitModeBox->isChecked() ) {
+      split = "SPLIT";
+    }
+  } else {
+    splitModeBox->hide();
+    this->cf3 = false;
+    rigidBox->setDisabled(false);
+    invertFragBox->setDisabled(false);
+    runExtBox->setDisabled(false);
+    replaceModeBox->setDisabled(false);
+  }
+  target_atoms = getSelectedAtomsList();
   QString putreplace = QString("PUT ");
   if (replace) {
       putreplace = QString("REPLACE ");
   }
-  if (target_atoms.split(" ").length() != 3) {
-    target_atoms = "<font color=red> Please select 3 target atoms/q-peaks! </font>";
-  }
-  if (mygl->source_atoms.split(" ").length() != 3){
-    mygl->source_atoms = "<font color=red> Please select 3 fragment atoms! </font>";
+  if (!cf3) {
+    if (target_atoms.split(" ").length() != 3) {
+      target_atoms = "<font color=red> Please select 3 target atoms/q-peaks! </font>";
+    }
+    if (mygl->source_atoms.split(" ").length() != 3){
+      mygl->source_atoms = "<font color=red> Please select 3 fragment atoms! </font>";
+    }
+  } else {
+    if (target_atoms.split(" ").length() != 1) {
+      target_atoms = "<font color=red> Please select <b>one</b> carbon atom! </font>";
+    }
+    mygl->source_atoms = "";
   }
   QString resistr = "RESI ";
   if (!residueOptionsBox->isChecked()) {
@@ -786,17 +845,22 @@ void DSRGui::combineOptionstext(void)
       resistr = "RESI "+resiclassEdit->text();
     }
   }
+  QString with;
+  if (cf3) {
+    with = QString(" ");
+  } else {
+    with = QString(" WITH ");
+  }
   QString outstring = QString(QString("REM DSR ")+putreplace+fragmentNameTag+" "+
-                          QString(" WITH ")+mygl->source_atoms+" "+QString("ON ")+
-                          target_atoms+" "+part+" "+fvarocc+" "+dfix+" "+resistr);
+                          with+mygl->source_atoms+" "+QString("ON ")+
+                          target_atoms+" "+part+" "+fvarocc+" "+dfix+" "+resistr+split);
   combiDSRline = outstring.simplified().toUpper();
   outtext->append(combiDSRline);
 }
 
 
-void DSRGui::setResiClass(QString rclass)
+void DSRGui::setResiClass(QString rclass) {
 //! defines the residue class
-{
   if (rclass[0].isLetter()){
     if (rclass.length() > 4) {
       resiclassEdit->setText(QString(rclass.mid(0, 4)));
@@ -809,9 +873,8 @@ void DSRGui::setResiClass(QString rclass)
   }
 }
 
-void DSRGui::setFragName(QModelIndex name)
+void DSRGui::setFragName(QModelIndex name) {
 //! set the fragment name variable
-{
   outtext->clear();
   fragmentNameTag = name.sibling(name.row(), 0).data().toString();
   writeFavorites(fragmentNameTag);
@@ -835,15 +898,14 @@ void DSRGui::setFragName(QModelIndex name)
   if (header->cell.isEmpty()){
     return;
   }
-  emit optionTextChanged();
+  //emit optionTextChanged();
   emit fragmentSelected();
   emit currentFragmentChanged(*header);
 }
 
 
-void DSRGui::DFIX(bool checked)
+void DSRGui::DFIX(bool checked) {
 //! toggles the dfix option
-{
   outtext->clear();
   if (checked)
   {
@@ -855,27 +917,25 @@ void DSRGui::DFIX(bool checked)
   emit optionTextChanged();
 }
 
-void DSRGui::setFvarOcc(QString focc)
-//! defines the PART option
-{
+void DSRGui::setFvarOcc(void) {
+//! defines the FVAR and occupancy option
   outtext->clear();
-  bool ok;
-  focc.toFloat(&ok);
-  if (ok)
-  {
-    fvarocc = QString("OCC ")+QString::number(focc.toFloat());
-  } else if (!ok and focc.length() >= 1) {
-    outtext->append(QString("Please provide a "
-                              "real number for FVAR/OCC"));
-  } else if (!ok and focc.length() == 0) {
-    fvarocc.clear();
+  int fvar = 0;
+  double occ = 0;
+  double focc = 0;
+  fvar = fvarspinner->value();
+  occ = (occEdit->text().toDouble());
+  if (fvarspinner->value() < 0) {
+    focc = -(abs(fvar) * 10 + occ);
+  } else {
+    focc = fvar * 10 + occ;
   }
+  fvarocc = QString("OCC ")+QString::number(focc);
   emit optionTextChanged();
 }
 
-void DSRGui::setPART(int partnum)
+void DSRGui::setPART(int partnum) {
 //! defines the PART option
-{
   outtext->clear();
   if (partnum == 0)
   {
@@ -889,9 +949,8 @@ void DSRGui::setPART(int partnum)
   emit optionTextChanged();
 }
 
-void DSRGui::fitDSRExtern(bool checked)
+void DSRGui::fitDSRExtern(bool checked) {
 //! enable write restraints to external file
-{
   if (checked) {
     this->runext = true;
   } else {
@@ -899,10 +958,9 @@ void DSRGui::fitDSRExtern(bool checked)
   }
 }
 
-void DSRGui::invertFrag(bool checked)
+void DSRGui::invertFrag(bool checked) {
 //! Inverts the fragment coordinates.
 //! They are also inverted in the 3D view.
-{
   // Invert coordinates in DSR:
   if (checked){
     this->invert = true;
@@ -957,9 +1015,8 @@ bool DSRGui::exportFrag(QString dirname) {
   return true;
 }
 
-void DSRGui::refineOrNot(bool checked)
+void DSRGui::refineOrNot(bool checked) {
 //! enable or disable refinement after transfer
-{
   if (checked) {
     this->norefine = true;
   } else {
@@ -967,9 +1024,8 @@ void DSRGui::refineOrNot(bool checked)
   }
 }
 
-void DSRGui::replaceOrNot(bool checked)
+void DSRGui::replaceOrNot(bool checked) {
 //! enable or disable replace mode
-{
   outtext->clear();
   if (checked) {
     this->replace = true;
@@ -980,45 +1036,82 @@ void DSRGui::replaceOrNot(bool checked)
 }
 
 QString DSRGui::getSelectedAtomsList() {
-  //! returns the currently selected atoms of the structure
-  //! loaded in ShelXle
+  //! returns the Names of the currently selected atoms of the structure
+  //! loaded in ShelXle as StringList
   QStringList atoms;
   atoms.clear();
   for (int i=0; i<m_molecule->selectedatoms.size(); i++) {
-    atoms.append(m_molecule->selectedatoms.at(i).Label);
+    atoms.append(m_molecule->selectedatoms.at(i).Label.toLatin1().replace(QChar(187), ">>"));
   }
   return atoms.join(" ");
 }
 
+QString DSRGui::getSelectedAtomsCoords() {
+  //! returns the atoms coordinates that are selected inside shelxle as a string
+  QString atoms = "";
+  QString line = "";
+  for (int i = 0; i < m_molecule->selectedatoms.size(); ++i) {
+    line = QString(" %1 %2 %3").arg(m_molecule->selectedatoms.at(i).frac.x, 10, 'f', 5)
+                               .arg(m_molecule->selectedatoms.at(i).frac.y, 10, 'f', 5)
+                               .arg(m_molecule->selectedatoms.at(i).frac.z, 10, 'f', 5);
+    atoms.append(line);
+  }
+  return atoms;
+}
+
 bool DSRGui::fitDSR() {
   /*!
    runs DSR from command line
 
    bool QDir::setCurrent(const QString & path)
-   QString QFileInfo::completeBaseName() const : c:\programme\dsr\p21c.res -> p21c.res
-   QString QFileInfo::absolutePath() const : c:\programme\dsr\p21c.res -> c:\programme\dsr\
-   QString QFileInfo::absoluteFilePath() const : c:\programme\dsr\p21c.res -> c:\programme\dsr\p21c.res
+   QString QFileInfo::completeBaseName() const : "c:/programme/dsr/p21c.res -> p21c.res
+   QString QFileInfo::absolutePath() const : c:/programme/dsr/p21c.res -> c:/programme/dsr/
+   QString QFileInfo::absoluteFilePath() const : c:/programme/dsr/p21c.res -> c:/programme/dsr/p21c.res
    QFileInfo fi("c:/temp/foo"); => fi.absoluteFilePath()
   */
-  if (m_molecule->selectedatoms.size() != 3) {
-    emit optionTextChanged();
-    return false;
-  }
-  if (mygl->source_atoms.split(" ").length() != 3) {
-    emit optionTextChanged();
-    return false;
+  QString atoms = getSelectedAtomsCoords();
+  if (!cf3) {
+    if (m_molecule->selectedatoms.size() != 3) {
+      emit optionTextChanged();
+      //return false;
+    }
+    if (mygl->source_atoms.split(" ").length() != 3) {
+      emit optionTextChanged();
+      outtext->append("<font color=red> \nPlease select three "
+                      "atoms of the fragment! </font>");
+      return false;
+    }
   }
+  info->hide(); // Even if the fit does not work, I want to hide it to better see the output
   QString option;
   QString target_atoms_tmp;
   QString source_atoms_tmp = mygl->source_atoms;
-  if (m_molecule->selectedatoms.size() < 3) {
-    outtext->clear();
+  if ((m_molecule->selectedatoms.size() != 3) && !cf3) {
+    //outtext->clear();
     outtext->append("<font color=red> Please select at least three "
                     "atoms or Q-peaks as target in your structure! </font>");
     return false;
   }
+  if ((m_molecule->selectedatoms.size() != 1) && cf3) {
+    outtext->clear();
+    outtext->append("<font color=red> Please select one carbon"
+                    "atom as target in your structure! </font>");
+    return false;
+  }
   target_atoms = getSelectedAtomsList();
   target_atoms_tmp = target_atoms;
+  bool ok;
+  int dsrv = dsrVersion.toInt(&ok, 10);
+  if (ok && dsrv < 200) {
+    // This is obsolete with DSR >= 200 since we fit the fragment to
+    // the actual coordinates and not to "names":
+    if ( target_atoms.contains(QString(">>"))) {
+      outtext->clear();
+      outtext->append(QString("<font color=red><b>Symmetrie generated atoms not allowed as target! <br><br>"
+                              "You might want to copy them (in a negative part).</b></font>"));
+      return false;
+    }
+  }
   emit optionTextChanged();
   bool save_sucess = m_shelxle->fileSave();
   if (!save_sucess) {
@@ -1037,6 +1130,7 @@ bool DSRGui::fitDSR() {
   QVector<int> previousLines = findDSRLines(reslist);
   QString wrappedDSRLine = textWrap(combiDSRline, 75);
   m_shelxle->insertDSRLine(wrappedDSRLine, DSRposition, previousLines);
+  delete reslist;
   dsrResulttext.clear();
   if (rigid) {
     option = "-g ";
@@ -1066,7 +1160,10 @@ bool DSRGui::fitDSR() {
   if (!m_shelxlPath.isEmpty() && (dsrVersion.toInt() > 182)) {
     option = " -shx " + m_shelxlPath + " " + option;
   }
-  QFileInfo resfip(resFileName);
+  if ((dsrVersion.toInt() >= 200)) {
+    option = " -target " + atoms + " " + option;
+  }
+  QFileInfo resfip(m_shelxle->dirName);
   QFileInfo check_res(resfip.completeBaseName()+".res");
   if ( resfip.completeSuffix() == "ins" && check_res.size() == 0) {
     outtext->clear();
@@ -1095,6 +1192,7 @@ bool DSRGui::fitDSR() {
   outtext->append(combiDSRline);
   outtext->append(dsrResulttext);
   m_shelxle->loadAFile();
+  this->raise();
   return true;
 }
 
@@ -1107,6 +1205,7 @@ void DSRGui::updateDSR() {
   dsr.closeWriteChannel();
   QString option = " -u";
   dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
+  outtext->append("Update running...");
   if (!dsr.waitForFinished())
   {
     dsrResulttext.append("Unable to start DSR.");
@@ -1166,7 +1265,7 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
   //! The -lc parameter of DSR returns a semicolon (;;) separated list
   //! tag;;fullname;;line number;;db
   if (QString("None") == fav) {
-    fav = loadFavoriteFragment().toAscii().toUpper();
+    fav = loadFavoriteFragment().toLatin1().toUpper();
   }
   QString *fraglist = new QString;
   fragmentsList->clear();
@@ -1278,7 +1377,7 @@ void DSRGui::displayFragmentsList(QStringList list, QString fav="None") {
     FragListmodel->setItem(i, 0, new QStandardItem(QString(column1)));
     FragListmodel->setItem(i, 1, nameItem);
     // load the last fragment:
-    if (fav == line.at(0).toAscii().toUpper()) {
+    if (fav == line.at(0).toLatin1().toUpper()) {
       if (FragListmodel->hasIndex(i, 0)) {
         setFragName(FragListmodel->index(i, 0));
       }
@@ -1292,7 +1391,7 @@ void DSRGui::displayFragmentsList(QStringList list, QString fav="None") {
   fragmentTableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
 }
 
-QString DSRGui::getDSRDir(){
+QString DSRGui::getDSRDir() {
   //! returns the value of the DSR_DIR variable
   //! in case of error, it returns an empty string
   QString dsrdir = qgetenv("DSR_DIR").data();
@@ -1316,7 +1415,7 @@ QString DSRGui::getDSRDir(){
   return QDir::fromNativeSeparators(dsrdir);
 }
 
-QString DSRGui::getDSRdbDir(){
+QString DSRGui::getDSRdbDir() {
   //! returns the directory with the userdb -> the home directory
   QString dbdir = QDir::homePath();
   return QDir::fromNativeSeparators(dbdir);;
