@@ -12,6 +12,9 @@
 #define DSRGUI_H
 
 #include <QtGui>
+#if (QT_VERSION >= 0x050000)
+#include <QtWidgets>
+#endif 
 #include <QDialog>
 #include <QModelIndex>
 #include <QNetworkAccessManager>
@@ -49,6 +52,7 @@ public:
   QSize sizeHint() const;
 private:
   QString getSelectedAtomsList();  //!< returns the list of the selected atoms in ShelXle
+  QString getSelectedAtomsCoords();  //!< returns the coordinates of the selected atoms in ShelXle
   Molecule *m_molecule;            //!< A pointer to the molecule object in ShelXle
   Window *m_shelxle;               //!< The Window object of ShelXle
   QVector<QStringList> *fragmentsList;   //!< tag;;fullname;;line number;;db
@@ -56,21 +60,23 @@ private:
   QTextBrowser *info;              //!< Information table with bond distances of fitted fragments
   QLineEdit *SearchInp;            //!< Search input field
   QLineEdit *occEdit;              //!< Input field for the SHELXL occupancy
-  QLineEdit *resinumEdit;
-  QLineEdit *resiclassEdit;
+  //QLineEdit *resinumEdit;          //!< Input field for residue numbers (obsolete, because is automatically determined)
+  QLineEdit *resiclassEdit;        //!< Input field for the residue class
   QVBoxLayout *mainVLayout;
   QHBoxLayout *editLayout;
-  QVBoxLayout *optionsLayout1;
-  QVBoxLayout *optionsLayout2;
-  QVBoxLayout *optionsLayout3;
-  QVBoxLayout *buttonLayout;
+  QVBoxLayout *optionsLayout1;     //!< Layout for the PARt FVAR OCC replace options
+  QVBoxLayout *optionsLayout2;     //!< Layout for invert external and rigid group options
+  QVBoxLayout *optionsLayout3;     //!< Layout for the residue and user manual options
+  QVBoxLayout *buttonLayout;       //!< Layout for fit, export and edit buttons
   QHBoxLayout *searchLayout;
   QHBoxLayout *partLayout;
+  QHBoxLayout *fvarLayout;
   QHBoxLayout *occLayout;
   QHBoxLayout *resclassLayout;
   QGridLayout *chooserLayout;
   QHBoxLayout *optionboxes;
   QSpinBox    *partspinner; //!< part definition spinbox
+  QSpinBox    *fvarspinner; //!< part definition spinbox
   QPushButton *editButton;
   QPushButton *fitDSRButton;
   QPushButton *exportFragButton;
@@ -83,22 +89,25 @@ private:
          *resiLabel,
          *classLabel,
          *resiTextLabel,
-         *usermanualLabel;
+         *usermanualLabel,
+         *fvarLabel;
   QTableView *fragmentTableView;   //!< list of fragments from DSR
-  QString resFileName;       //!< Name of the currently processed res file
   QString dsrResulttext;     //!< Resulting output text of a dsr run
   QString *resnumbertext;    //!< The text string that tells about the residue number
   QCheckBox *runExtBox,      //!< Enable external restraints button
             *invertFragBox,  //!< enable/disable inverted fragment coordinates
             *dfixBox,        //!< enable/disable rigid group instead of restraints
             *replaceModeBox, //!< enable replace mode
-            *rigidBox;       //!< keep fragment as rigid AFIX 9 group and omit restraints
-  bool runext;
-  bool invert;
+            *rigidBox,       //!< keep fragment as rigid AFIX 9 group and omit restraints
+            *splitModeBox;   //!< Only for CF6 fragment. Enables spitting of pivot carbon atom
+  bool runext;               //!< Should DSR write external restraints file?
+  bool invert;               //!< Should DSr invert the coordinates?
   bool norefine;
   bool replace;
   bool rigid;
   bool resiIsEnabled;
+  bool cf3;
+  bool splitmode;
   QString export_dir;
   QString target_atoms;
   QString dfix;
@@ -113,7 +122,6 @@ private:
   void displayFragmentsList(QStringList list, QString fav);
   QString getDSRDir();
   QString getDSRdbDir();
-  void prepareOuttext();
   void connect_signals_and_slots();
   void setToolTips();
   QString textWrap(QString inText, int length);
@@ -148,7 +156,7 @@ public slots:
   bool exportFrag(QString dirname);
   void DFIX(bool checked);
   void setPART(int part);
-  void setFvarOcc(QString focc);
+  void setFvarOcc(void);
   void setResiClass(QString rclass);
   void combineOptionstext(void);
   void setExportDirDialog(void);
