@@ -748,9 +748,9 @@ void EacDlg::importSettings(){
   mol->bondColorStyle = eaSettings->value("BondStyle").toInt();;
   mol->bondStrength = eaSettings->value("BondStrength").toDouble();
 
-  mol->enviBondColor=eaSettings->value("enviBondColor",Qt::darkGreen).value<QColor>();
-  mol->enviHBColor=eaSettings->value("enviHBColor",Qt::darkYellow).value<QColor>();
-  mol->enviDefaultColor=eaSettings->value("enviDefaultColor",Qt::black).value<QColor>();
+  mol->enviBondColor=eaSettings->value("enviBondColor",QColor(Qt::darkGreen)).value<QColor>();
+  mol->enviHBColor=eaSettings->value("enviHBColor",QColor(Qt::darkYellow)).value<QColor>();
+  mol->enviDefaultColor=eaSettings->value("enviDefaultColor",QColor(Qt::black)).value<QColor>();
   
   eaSettings->endGroup();
   delete eaSettings;
