@@ -32,6 +32,9 @@
 class EacGLW: public QGLWidget {
 Q_OBJECT
   public:
+  GLUquadric *myquad;
+
+  QGLShaderProgram *saveProgram;
   Molecule *mol;//!< pointer to ShelXle's Molecule object.
   double exmin,//!< Minimal Q-Peak electron density value of shelXle to be restored when the dialog is closed.
 	 exmax;//!< Maximal Q-Peak electron density value of shelXle to be restored when the dialog is closed.
@@ -43,6 +46,7 @@ Q_OBJECT
   QFont myFont;//!< a font for the atom labels
   //QStringList pse;
   QTimer *timer;//!< a timer for the molecule rotation
+  void setMSAA(bool);
   signals:
       void colorchanged(QColor bgcolor);//!< colorchanged is emitted  by the color dialog colorDLG to change the color of a chemical element. @param bgcolor the new color
  protected:
@@ -101,6 +105,7 @@ Q_OBJECT
   void colorchange(QColor bgcolor);//!< changes the color of the current element to bgcolor. Changes the color of the corresponding button.
   void updateLEs(int OZ);//!< when the current element changes the settings of this element are loaded and applied to the EacGLW widget and the PSEWidget. @param OZ atomic number (staring from zero) of the new atom
   void checkWall();//!< when solid is checked then solid is unchecked.
+  void checkShader(bool b);//!< when solid is checked then solid is unchecked.
   void checkSolid();//!< when walls are checked solid is unchecked. 
   void checkBall();//!< when ellipsoid surface is unchecked the solid checkbox is diabled. 
   void doMulti();//!< calls MultiStyle dialog
@@ -122,6 +127,8 @@ Q_OBJECT
  private:
   Molecule *mol;
   //MyAtom *otm;
+
+  QCheckBox *shaderUse; 
   QDoubleSpinBox *bondStrength;
   QSpinBox *lodSpinBox;
   QComboBox *eacProba;
