@@ -23,6 +23,7 @@
 FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol, double wght){
   mole =mole_;
   n1=n2=n3=n4=n5=0;
+  voxelstr.clear();
   chgl=chgl_;
   oldatomsize=-1;
   map_radius=5.0;
@@ -238,6 +239,17 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
       for (int i=0; it[i]< j; i++)n2=it[i+1];
       j=(int)(rr*ml+.5);
       for (int i=0; (it[i]< j)||((nc)&&(it[i]%2)); i++) n3=it[i+1];
+      if (!voxelstr.isEmpty()) {
+        if (voxelstr.contains('x')) {
+          QStringList lll=voxelstr.split('x');
+          if (lll.size()==3){
+          n1=lll.at(0).toInt();
+          n2=lll.at(1).toInt();
+          n3=lll.at(2).toInt();
+          printf("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n %d %d %d \n",n1,n2,n3);
+          }
+        }
+      }
       n4=n2*n1;
       n5=n3*n4;
       datfo=(float*) malloc(sizeof(float)*n5);
@@ -278,8 +290,12 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
 	  if((abs(j-lr[i].ih)+abs(k-lr[i].ik)+abs(l-lr[i].il))==0)s+=1.0;
 	  if(abs(j+lr[i].ih)+abs(k+lr[i].ik)+abs(l+lr[i].il)==0)t+=1.0;
 	}
+        if (i==0) {//printf("v%f s%f t%f\n",C[14],s,t);
+          s=1;t=0;//f000 
+        }
         if(typ==0) ss=(lr[i].fo-lr[i].fc)/(C[14]*(s+t));
-	else if(typ==2) ss=(lr[i].fc)/(C[14]*(s+t));
+	else if(typ==2) //here this happens never
+          ss=(lr[i].fc)/(C[14]*(s+t));
         else ss=(lr[i].fo)/(C[14]*(s+t));
 	if(lr[i].fc>1.E-6) ss=ss/(1.+rw*pow(lr[i].so/lr[i].fc,4));
 	for (int n=0; n<ns;n++){
@@ -460,6 +476,138 @@ void FourXle::deletes(char *s, int count){
   trimm(s);
 }
 
+void FourXle::exportMaps(int na, const char filename[], const char atomlist[]){
+  if ((datfo==NULL)||(datfo_fc==NULL)) return;
+  FILE *fo,*fof1;//,*f1f2;
+  char foname[4096];
+  char fof1name[4096];
+//  char f1f2name[4096];
+  int len=strlen(filename);
+  float factor=0.1481847095290449;//a0**3
+  double a0=0.52917720859;  //bohr=0.5291775108
+  int i=0;
+  //
+  //FO MAP
+  //
+  V3 dx1=V3(1.0/(n1),0,0);
+  V3 dy1=V3(0,1.0/(n2),0);
+  V3 dz1=V3(0,0,1.0/(n3));
+  mole->frac2kart(dx1,dx1); 
+  mole->frac2kart(dy1,dy1); 
+  mole->frac2kart(dz1,dz1);     
+
+  strncpy(foname,filename,len-4);
+  foname[len-4]='\0';
+  strcat(foname,"_fo_densitymap.cube");
+  fo=fopen(foname,"w");
+  if (fo==NULL) return ;
+  double fomax=-9e37,fomin=9e37,em=0,ep=0,et=0;
+  for (int i=0; i<n5; i++ ){
+    if (datfo[i]>0.0) ep+=datfo[i];
+    else em+=datfo[i];
+    et+=datfo[i];
+    fomax=fmax(datfo[i],fomax);
+    fomin=fmin(datfo[i],fomin);
+  }
+  printf("Fo %g %g %g %g %g\n",fomin,fomax,ep/n5*C[14],em/n5*C[14],et/n5*C[14] );
+  fprintf(fo,"F observed map written by ShelXle\nDensity obtained from Fo in fcf with phases of model transformed using fft\n");
+  fprintf(fo,"%5d%12.6f%12.6f%12.6f\n",na,
+      (dx1.x+dy1.x+dz1.x)*0.5/a0,
+      (dx1.y+dy1.y+dz1.y)*0.5/a0,
+      (dx1.z+dy1.z+dz1.z)*0.5/a0
+      //0.0,0.0,0.0
+      );
+  fprintf(fo,"%5d%12.6f%12.6f%12.6f\n",n1,dx1.x/a0,dx1.y/a0,dx1.z/a0);
+  fprintf(fo,"%5d%12.6f%12.6f%12.6f\n",n2,dy1.x/a0,dy1.y/a0,dy1.z/a0);
+  fprintf(fo,"%5d%12.6f%12.6f%12.6f"  ,n3,dz1.x/a0,dz1.y/a0,dz1.z/a0);//no newline here because it is in atomlist
+  fprintf(fo,"%s",atomlist);
+  for (int xi=0;xi<n1;xi++)
+    for (int yi=0;yi<n2;yi++)
+      for (int zi=0;zi<n3;zi++)
+      {
+        //fprintf(fo,"%s%13.5E",(((i%6)==0)?"\n":""),datfo[dex(xi,yi,zi)]*factor);
+        fprintf(fo,"%s",QString("%1%2").arg(((i%6)==0)?"\n":"").arg(datfo[dex(xi,yi,zi)]*factor,13,'E',5).toStdString().c_str());
+        i++;
+      }
+  fclose(fo);
+  //
+  //FO-F1 MAP
+  //
+
+  strncpy(fof1name,filename,len-4);
+  fof1name[len-4]='\0';
+  strcat(fof1name,"_fo-fc_densitymap.cube");
+  fof1=fopen(fof1name,"w");
+  if (fof1==NULL) return ;
+  fomax=-9e37;
+  fomin= 9e37;
+  em=0;
+  ep=0;
+  et=0;
+  for (int i=0; i<n5; i++ ){
+    if (datfo_fc[i]>0.0) ep+=datfo_fc[i];
+    else em+=datfo_fc[i];
+    et+=datfo_fc[i];
+    fomax=fmax(datfo_fc[i],fomax);
+    fomin=fmin(datfo_fc[i],fomin);
+  }
+  printf("Fo-Fc %g %g %g %g %g\n",fomin,fomax,ep/n5*C[14],em/n5*C[14],et/n5*C[14] );
+  fprintf(fof1,"F obs-fc map written by ShelXle\nDifferene density Fo-fc in fcf file transformed using fft\n");
+  fprintf(fof1,"%5d%12.6f%12.6f%12.6f\n",na,
+      (dx1.x+dy1.x+dz1.x)*0.5/a0,
+      (dx1.y+dy1.y+dz1.y)*0.5/a0,
+      (dx1.z+dy1.z+dz1.z)*0.5/a0
+      //0.0,0.0,(dx.z+dy.z+dz.z)/a0
+      );
+  fprintf(fof1,"%5d%12.6f%12.6f%12.6f\n",n1,dx1.x/a0,dx1.y/a0,dx1.z/a0);
+  fprintf(fof1,"%5d%12.6f%12.6f%12.6f\n",n2,dy1.x/a0,dy1.y/a0,dy1.z/a0);
+  fprintf(fof1,"%5d%12.6f%12.6f%12.6f"  ,n3,dz1.x/a0,dz1.y/a0,dz1.z/a0);//no newline here because it is in atomlist
+  fprintf(fof1,"%s",atomlist);
+  for (int xi=0;xi<n1;xi++)
+    for (int yi=0;yi<n2;yi++)
+      for (int zi=0;zi<n3;zi++)
+      {
+        //fprintf(fof1,"%s%13.5E",(((i%6)==0)?"\n":""),datfo_fc[dex(xi,yi,zi)]*factor);
+        fprintf(fof1,"%s",QString("%1%2").arg(((i%6)==0)?"\n":"").arg(datfo_fc[dex(xi,yi,zi)]*factor,13,'E',5).toStdString().c_str());
+        i++;
+      }
+  fclose(fof1);
+  //
+  //F1-F2 MAP
+  //
+
+  /*
+  if (datf1_f2!=NULL){
+    strncpy(f1f2name,filename,len-4);
+    f1f2name[len-4]='\0';
+    strcat(f1f2name,"_fmod1-fmod2_densitymap.cube");
+    f1f2=fopen(f1f2name,"w");
+    if (f1f2==NULL) return ;
+    fprintf(f1f2,"F fmod1-fmod2 map written by MoleCoolQt\nDifferene density fmod1-fmod2 in xd.fou transformed using fft\n");
+    fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",na,
+        (dx1.x+dy1.x+dz1.x)*0.5/a0,
+        (dx1.y+dy1.y+dz1.y)*0.5/a0,
+        (dx1.z+dy1.z+dz1.z)*0.5/a0
+        //0.0,0.0,(dx.z+dy.z+dz.z)/a0
+        );
+    fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",n1,dx1.x/a0,dx1.y/a0,dx1.z/a0);
+    fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",n2,dy1.x/a0,dy1.y/a0,dy1.z/a0);
+    fprintf(f1f2,"%5d%12.6f%12.6f%12.6f"  ,n3,dz1.x/a0,dz1.y/a0,dz1.z/a0);//no newline here because it is in atomlist
+    fprintf(f1f2,"%s",atomlist);
+    for (int xi=0;xi<n1;xi++)
+      for (int yi=0;yi<n2;yi++)
+        for (int zi=0;zi<n3;zi++)
+        {
+          //   fprintf(f1f2,"%s%13.5E",(((i%6)==0)?"\n":""),datf1_f2[dex(xi,yi,zi)]*factor);
+          fprintf(f1f2,"%s",QString("%1%2").arg(((i%6)==0)?"\n":"").arg(datf1_f2[dex(xi,yi,zi)]*factor,13,'E',5).toStdString().c_str());
+          i++;
+        }
+
+    fclose(f1f2);
+  }
+// */
+}
+
 int FourXle::readHeader(const char *filename){
   /*! reads the header of an fcf file
    */
