@@ -42,9 +42,14 @@
 
  Highlighter::Highlighter(QTextDocument *parent)
      : QSyntaxHighlighter(parent){
- setEditStyle();
  }
 
+ Highlighter::Highlighter(QString FileName, QTextDocument *parent)
+     : QSyntaxHighlighter(parent){
+   //    setEditStyle();
+       loadHighlightPatterns(FileName);
+ }
+/*
  void Highlighter::setEditStyle(){
   outputstyle=false;
   HighlightingRule rule;
@@ -52,7 +57,7 @@
   keywordFormat.setForeground(Qt::darkRed);
   keywordFormat.setFontWeight(QFont::Bold);
   keywordFormat.setBackground(QColor("#aaffaa"));
-  QStringList keywordPatterns;
+/ *  QStringList keywordPatterns;
   keywordPatterns <<
    "ACTA"<<"AFIX"<<"AGS4"<<"ANIS"<<"BASF"<<"BIND"<<"BLOC"<<"BOND"<<
    "BUMP"<<"CELL"<<"CGLS"<<"CHIV"<<"CONF"<<"CONN"<<"DAMP"<<"DANG"<<
@@ -71,12 +76,12 @@
    "ATOM"<<//PDB dummy commands ...
    "HETA"<<//PDB dummy commands ...
    "SCAL"<<//PDB dummy commands ...
-	  "ABIN"<<
-	  "ANSC"<<
-	  "ANSR"<<
-	  "NOTR"<<
-	  "NEUT"<<
-	  "TWST";//<<
+   "ABIN"<<
+   "ANSC"<<
+   "ANSR"<<
+   "NOTR"<<
+   "NEUT"<<
+   "TWST";//<<
    
    ;
   foreach (QString pattern, keywordPatterns) {
@@ -96,19 +101,47 @@
     rule.format = keywordFormat;
     highlightingRules.append(rule);
 
-  }
-  rule.pattern = QRegExp("L[.]S[.]",Qt::CaseInsensitive);
+  }// * /
+  QString pattern = 
+    "(^)(ACTA)|(^)(AFIX)|(^)(MPLA)|(^)(ANIS)|(^)(BASF)|(^)(BIND)|(^)(BLOC)|"
+    "(^)(BOND)|(^)(BUMP)|(^)(CELL)|(^)(CGLS)|(^)(CHIV)|(^)(CONF)|(^)(CONN)|"
+    "(^)(DAMP)|(^)(DANG)|(^)(DEFS)|(^)(DELU)|(^)(DFIX)|(^)(DISP)|(^)(EADP)|"
+     "(^)(END)|(^)(EQIV)|(^)(EXTI)|(^)(EXYZ)|"
+    "(^)(FLAT)|(^)(FMAP)|(^)(FRAG)|(^)(FREE)|(^)(FVAR)|(^)(GRID)|(^)(HFIX)|"
+    "(^)(HKLF)|(^)(HOPE)|(^)(HTAB)|(^)(ISOR)|(^)(LAST)|(^)(LATT)|"
+    "(^)(LAUE)|(^)(LIST)|(^)(MERG)|(^)(MOLE)|(^)(MORE)|(^)(MOVE)|(^)(L\\.S\\.)|"
+    "(^)(NCSY)|(^)(OMIT)|(^)(PART)|(^)(PLAN)|"
+    "(^)(RESI)|(^)(RTAB)|(^)(SADI)|(^)(SAME)|(^)(SFAC)|"
+    "(^)(SHEL)|(^)(SIMU)|(^)(SIZE)|(^)(SPEC)|(^)(STIR)|(^)(SUMP)|"
+    "(^)(SWAT)|(^)(SYMM)|(^)(TEMP)|(^)(TIME)|"
+    "(^)(TWIN)|(^)(UNIT)|(^)(WPDB)|(^)(WGHT)|(^)(ZERR)";
+  rule.pattern = QRegExp(pattern,Qt::CaseInsensitive);
   rule.format = keywordFormat;
   highlightingRules.append(rule);
-/*
+
+  pattern= "(^)(EGEN)|(^)(PHAN)|(^)(PHAS)|(^)(SPIN)|(^)(TEXP)|"
+      "(^)(VECT)|(^)(PSEE)|(^)(TREF)|(^)(PATT)|(^)(ESEL)|(^)(INIT)";
+      
+  rule.pattern = QRegExp(pattern,Qt::CaseInsensitive);
+  rule.format = keywordFormat;
+  highlightingRules.append(rule);
+  pattern="(^)(XNPD)|"
+      "(^)(REST)|(^)(CHAN)|(^)(RIGU)|(^)(FLAP)|(^)(RNUM)|(^)(SOCC)|(^)(PRIG)|"
+      "(^)(WIGL)|(^)(RANG)|(^)(TANG)|(^)(ADDA)|(^)(STAG)|(^)(ATOM)|(^)(HETA)|"
+      "(^)(SCAL)|(^)(ABIN)|(^)(ANSC)|(^)(ANSR)|(^)(NOTR)|(^)(NEUT)|(^)(TWST)"; 
+
+  rule.pattern = QRegExp(pattern,Qt::CaseInsensitive);
+  rule.format = keywordFormat;
+  highlightingRules.append(rule);
+/ *
   keybitsFormat.setFontWeight(QFont::Black);
   keybitsFormat.setForeground(Qt::white);
   keybitsFormat.setBackground(Qt::darkGray);
   rule.pattern =  QRegExp("\\b[01]{3,3} [01]{6,6} [01]{10,10} [01]{15,15} [01]{2,2} [01]{3,3} [01]{5,5} [01]{7,7} [01]{9,9}");
   rule.format = keybitsFormat;
   highlightingRules.append(rule);
-  */
-  /*
+  * /
+  / *
   classFormat.setBackground(QColor("#aaffee"));
   rule.pattern = QRegExp(" =$");
   rule.format = classFormat;
@@ -116,8 +149,8 @@
   rule.pattern = QRegExp("^    ");
   rule.format = classFormat;
   highlightingRules.append(rule);
-  */
-/*
+  * /
+/ *
   QTextCharFormat xyzFormat;
   xyzFormat.setFontWeight(QFont::Bold);
   xyzFormat.setForeground(QColor(128,128,255));
@@ -135,7 +168,7 @@
   rule.pattern = QRegExp("\\bZ\\b");
   rule.format = xyzFormat;
   highlightingRules.append(rule);
-*/
+* /
 
 
   numberFormat.setFontWeight(QFont::Bold);
@@ -280,7 +313,7 @@ void Highlighter::setOutputStyle(){
 
   outputstyle=true; 
 }
-
+*/
 void Highlighter::highlightSearch(const QString &find){
   HighlightingRule rule;
   rule.format.setBackground(Qt::yellow);
@@ -301,13 +334,12 @@ void Highlighter::highlightSearch(const QString &find){
 void Highlighter::highlightError(const QStringList fnd){
   findRule.clear();
   HighlightingRule rule;
-  toolongFormat.setFontWeight(QFont::Black);
-  toolongFormat.setForeground(Qt::yellow);
-  toolongFormat.setFontUnderline(true);
-  toolongFormat.setUnderlineStyle(QTextCharFormat::WaveUnderline);
-  toolongFormat.setUnderlineColor(Qt::red);
-  toolongFormat.setBackground(QColor(Qt::red).lighter(100));
-  rule.format = toolongFormat;
+  rule.format.setFontWeight(QFont::Black);
+  rule.format.setForeground(Qt::yellow);
+  rule.format.setFontUnderline(true);
+  rule.format.setUnderlineStyle(QTextCharFormat::WaveUnderline);
+  rule.format.setUnderlineColor(Qt::red);
+  rule.format.setBackground(QColor(Qt::red).lighter(100));
   QString f="";
   for (int i=0;i<fnd.size();i++){
       f=fnd.at(i);
@@ -344,6 +376,7 @@ void Highlighter::highlightDupl(const CEnvironment &dupls){
 
 void Highlighter::highlightBlock(const QString &text) {
   foreach (HighlightingRule rule, highlightingRules) {
+    if (rule.Comment) continue;
     QRegExp expression(rule.pattern);
     int index = text.indexOf(expression);
     while (index >= 0) {
@@ -378,25 +411,17 @@ void Highlighter::highlightBlock(const QString &text) {
     if (fmt.foreground()==Qt::blue) startIndex=-1;
     if (fmt.underlineStyle()) startIndex=-1;
   }
+  foreach (HighlightingRule rule, highlightingRules) {
+    if (!rule.Comment) continue;
+    QRegExp expression(rule.pattern);
+    int index = text.indexOf(expression);
+    while (index >= 0) {
+      int length = expression.matchedLength();
+      setFormat(index, length, rule.format);
+      index = text.indexOf(expression, index + length);
+     // printf("in editor height = %d\n",QFontMetrics(rule.format.font()).height());
+    }
   }
-  HighlightingRule rule;
-  rule.pattern = QRegExp("![^\n]*");
-  rule.format = singleLineCommentFormat;
-  QRegExp expression(rule.pattern);
-  int index = text.indexOf(expression);
-  while (index >= 0) {
-    int length = expression.matchedLength();
-    setFormat(index, length, rule.format);
-    index = text.indexOf(expression, index + length);
-  }
-  rule.pattern = QRegExp("REM [^\n]*");
-  rule.format = singleLineCommentFormat;
-  expression = QRegExp(rule.pattern);
-  index = text.indexOf(expression);
-  while (index >= 0) {
-    int length = expression.matchedLength();
-    setFormat(index, length, rule.format);
-    index = text.indexOf(expression, index + length);
   }
 /*
   rule.pattern =  QRegExp("\\b[0-9]{2,}\\.[0-9]+\\b");
@@ -420,3 +445,53 @@ void Highlighter::highlightBlock(const QString &text) {
   }
 //  printf("hi blo\n");
 }
+
+void Highlighter::loadHighlightPatterns(QString FileName){
+  //int group=1;  
+  highlightingRules.clear();
+  outputstyle=true;
+  //  fprintf(stderr,"loadHighlightPatterns %s\n",FileName.toStdString().c_str());
+  QSettings *pat = new QSettings(FileName,QSettings::IniFormat);
+  /*foreach(HighlightingRule rule, highlightingRules){  
+    pat->beginGroup(QString("%1").arg(group));
+    pat->setValue("Pattern"     ,rule.pattern.pattern());
+    pat->setValue("Color"           ,rule.format.foreground().color().name());
+    pat->setValue("Background"      ,rule.format.background().color().name());
+    pat->setValue("Weight"          ,rule.format.fontWeight());
+    pat->setValue("Underlined"      ,rule.format.fontUnderline());
+    pat->setValue("UnderlineStyle"  ,rule.format.underlineStyle());
+    pat->setValue("UnderlineColor"  ,rule.format.underlineColor().name());
+    pat->setValue("Overlined"       ,rule.format.fontOverline());
+    pat->setValue("CaseSensitive"   ,rule.pattern.caseSensitivity()); 
+    pat->endGroup();
+    group++;
+    }*/
+  HighlightingRule rule;
+  QStringList groups = pat->childGroups();
+  foreach (QString grp,groups){
+    if (!grp.contains(QRegExp("\\D+"))){
+      pat->beginGroup(grp);
+      rule.pattern.setPattern(pat->value("Pattern","").toString());
+      rule.format.setForeground(QColor(pat->value("Color"           ,"#000000").toString()));
+      rule.format.setBackground(QColor(pat->value("Background"      ,"#ffffff").toString()));
+      rule.format.setFontWeight(pat->value("Weight"          ,50).toInt());
+      rule.format.setFontUnderline(pat->value("Underlined"      ,"false").toBool());
+      rule.format.setUnderlineStyle((QTextCharFormat::UnderlineStyle) pat->value("UnderlineStyle"  ,"1").toInt());
+      rule.format.setUnderlineColor(QColor(pat->value("UnderlineColor"  ,rule.format.foreground().color().name()).toString()));
+      rule.format.setFontOverline(pat->value("Overlined"       ,"false").toBool());
+      rule.Comment=pat->value("Comment","false").toBool();
+      rule.pattern.setCaseSensitivity((Qt::CaseSensitivity)pat->value("CaseSensitive"   ,0).toInt());
+      pat->endGroup();
+      highlightingRules.append(rule);
+    }else{
+      pat->beginGroup(grp);
+      multiLineCommentFormat.setForeground(QColor(pat->value("MultilineColor" ,"#000000").toString()));
+      multiLineCommentFormat.setBackground(QColor(pat->value("MultilineBackground" ,"#eefffe").toString()));
+      multiLineCommentFormat.setFontUnderline(pat->value("MultilineUnderlined"      ,"false").toBool());
+      commentStartExpression.setPattern(pat->value("MultilineStart","=\\s*$").toString());
+      commentEndExpression.setPattern(pat->value("MultilineiEnd","^ [^=]*$").toString());
+      outputstyle=false;
+    }
+  }
+  //fprintf(stderr,"finished loadHighlightPatterns %s outputstyle=%s\n",FileName.toStdString().c_str(),(outputstyle)?"true":"false");
+}
