@@ -10,15 +10,12 @@
  *
  */
 
-ListFileHandler::ListFileHandler(QString lstpath, QString lstname, QObject *parent) : QObject(parent)
+ListFileHandler::ListFileHandler(QString lfpath, QObject *parent) : QObject(parent)
 {
   REL_RESTR_CARDS << "SAME"<< "SADI"<< "SIMU"<< "RIGU"<< "ISOR"<< "NCSY"<< "FLAT" << "DELU";
-  QFileInfo fi;
-  fi.setFile(lstpath, lstname);
-  full_lstpath = fi.absoluteFilePath();
-  my_lstname = &lstname;
-  QFileSystemWatcher fw;
-  fw.addPath(full_lstpath);
+  my_lstpath = lfpath;
+  //QFileSystemWatcher fw;  // The filesystem watcher doesn't work in my windows 8.1
+  //fw.addPath(*my_lstpath);  // I am not shure why I added it? It works also without
   success = false; // turns to true if refinement was a sucess.
   listfcontent = new QStringList;
   listfcontent->append(this->loadLst());
@@ -28,7 +25,7 @@ ListFileHandler::ListFileHandler(QString lstpath, QString lstname, QObject *pare
 QStringList ListFileHandler::loadLst(){
   //! Reads the SHELXL lst file from disk
   //! and returns it as a QStringlist
-  QFile file(full_lstpath);
+  QFile file(my_lstpath);
   QStringList lstList;
   if (file.open(QFile::ReadOnly | QFile::Text)) {
     QTextStream textStream(&file);
@@ -167,7 +164,7 @@ QString ListFileHandler::table_maker(QVector<QStringList> tabledata) {
       table.append(this->row(line));
     }
     header = QString(
-        "<body style=\"font-family:SansSerif; font-size:12pt;\">"
+        "<body style=\"font-family:SansSerif; font-size:11pt;\">"
         "<table>"
         "<tr>"
           "<td width=60% align=left>"
@@ -215,10 +212,10 @@ QString ListFileHandler::row(QStringList rowdata) {
       rowdata[2].toFloat(&ok1);
       rowdata[3].toFloat(&ok2);
       if (ok1 && ok2) {
-        if (qAbs(rowdata.at(2).toFloat()) > 2.5*rowdata[3].toFloat()) {
+        if (qAbs(rowdata.at(2).toDouble()) > 2.5*rowdata[3].toDouble()) {
           bgcolor = QString("bgcolor='#ffec99'"); // bgcolor='#FFD100'  // yellow
         }
-        if (qAbs(rowdata.at(2).toFloat()) > 3.5*rowdata[3].toFloat()) {
+        if (qAbs(rowdata.at(2).toDouble()) > 3.5*rowdata[3].toDouble()) {
           bgcolor = QString("bgcolor='#ff9fac'"); // bgcolor='#FF1030'  // red
         }
       }
@@ -290,8 +287,7 @@ QString ListFileHandler::thetaFromLst() {
 // ##########################################################################
 
 
-XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent)
-{
+XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent) {
   //! Handles the content of the SHELXL list file.
   //! Methods with "current" in the name return values of the current state
   //! in the continuously growing SHELXL list file.
@@ -306,9 +302,9 @@ XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent)
   listf_data.rsigma = "";
   listf_data.wr2 = "";
   listf_data.cycle = "";
-  listf_data.data = "";
-  listf_data.current_parameters = "";
-  listf_data.all_parameters = "";
+  listf_data.data = "0";
+  listf_data.current_parameters = "0";
+  listf_data.all_parameters = "0";
   listf_data.curGoof = " ";
   listf_data.curRGoof = " ";
   listf_data.R1_4sig = "";
@@ -327,6 +323,7 @@ XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent)
   listf_data.holedist = "";
   listf_data.warning = "";
   listf_data.warnings.clear();
+  listf_data.time = "";
 
   rgr.Goof = 0.0;
   rgr.cycle = 0.0;
@@ -340,6 +337,7 @@ XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent)
   rgr.maxshiftfor = "";
   rgr.meanshift = 0.0;
   rgr.warnings.clear();
+  rgr.time = 0.0;
   warnings.clear();
 }
 
@@ -379,6 +377,7 @@ void XLOutputParser::fillListFileData(QString line) {
   QStringList meanshifts = xl_current_meanshift_esd(line);
   xl_collect_warnings(line);
   QStringList flackvals = xl_flacksvals(line);
+  QString timeval = xl_timeval(line);
 
   // Only fill listf_data with values if there are any:
   if (!cmdline.isEmpty()) {
@@ -462,96 +461,135 @@ void XLOutputParser::fillListFileData(QString line) {
   if (!flackvals[1].isEmpty()) {
     listf_data.parson = flackvals.at(1);
   }
+  if (!timeval.isEmpty()) {
+    listf_data.time = timeval;
+  }
 }
 
-QString XLOutputParser::residualsTextDisplay(QString line){
+QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
   //! returns a html string to display the refinement results in a QLabel
   fillListFileData(line);
-  QString html_final;
-  QString wr2line;
+  QString html_final = "";
+  QString wr2line = "";
   QString shiftyellow = "";
   QString dUyellow = "";
+  QString cycleText = "";
+  QString progressbar = "";
   if (!listf_data.R1_4sig.isEmpty() && !listf_data.finalwR2.isEmpty()) { // final values:
     html_final = QString("<tr><td align=right><b><i>wR</i><sub>2</sub> = </b></td> <td><b> %2% </b>(all data) </td>"
                          "    <td align=right><b><i>R</i><sub>1</sub></b> [<i>I</i> > 4&sigma;<i>I</i>] = </td> <td><b>%1%</b> (%9% all data)</td></tr>"
-                         "<tr><td align=right>Highest peak = </td> <td> %3 e&#8491;<sup>-3</sup> at %4 &#8491; from %7 </td>"
+                         "<tr><td align=right>Highest peak = </td> <td> %3 e&#8491;<sup>-3</sup> at %4 &#8491; from %7 &nbsp;&nbsp;&nbsp;&nbsp;</td>"
                          "    <td align=right>Deepest hole = </td> <td> %5 e&#8491;<sup>-3</sup> at %6 &#8491; from %8 </td></tr>"
                          )
-          .arg(listf_data.R1_4sig.toFloat()*100, 4, 'f', 2, 0)      // 1
-          .arg(listf_data.finalwR2.toFloat()*100, 4, 'f', 2, 0)     // 2
+          .arg(listf_data.R1_4sig.toDouble()*100, 4, 'f', 2, 0)      // 1
+          .arg(listf_data.finalwR2.toDouble()*100, 4, 'f', 2, 0)     // 2
           .arg(listf_data.peak)           // 3
           .arg(listf_data.peakdist)       // 4
           .arg(listf_data.hole)           // 5
           .arg(listf_data.holedist)       // 6
           .arg(listf_data.peakfrom)       // 7
           .arg(listf_data.holefrom)       // 8
-          .arg(listf_data.R1_all.toFloat()*100, 4, 'f', 2, 0)       // 9
+          .arg(listf_data.R1_all.toDouble()*100, 4, 'f', 2, 0)       // 9
         ;
     if (!listf_data.flack.isEmpty() || !listf_data.parson.isEmpty()) {
       if (!listf_data.parson.isEmpty()) {
-        wr2line = QString("<tr><td align=right> Flack X = </td> <td> %1 (Parsons' method)</td> "
+        wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (Parsons' method)</td> "
                            "<td>  </td> </tr>").arg(listf_data.parson);
       }
       if (!listf_data.flack.isEmpty()) {
-        wr2line = QString("<tr><td align=right> Flack X = </td> <td> %1 (classical fit)</td> "
+        wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (classical fit)</td> "
                                   "<td>  </td> </tr>").arg(listf_data.flack);
       }
     } else { // no flack parameter:
-      wr2line = "<tr><td> </td></tr>";
+      wr2line = ""; // No Table row to prevent empty line
     }
   } else {  // shelxl is currently runnig:
     html_final = "";
     wr2line = QString("<tr><td align=right> <i>wR</i><sub>2</sub> =   </td> <td> %7% </td></tr>")
-                      .arg(listf_data.wr2.toFloat()*100, 4, 'f', 2);
+                      .arg(listf_data.wr2.toDouble()*100, 4, 'f', 2);
   }
-  if (qAbs(listf_data.maxshift.toFloat()) > 0.005) {
-    shiftyellow = QString("bgcolor='#ffec99'");
+  if (qAbs(listf_data.maxshift.toDouble()) > 0.005) {
+    shiftyellow = QString("bgcolor=#ffec99");
   }
-  if (qAbs(listf_data.dU.toFloat()) > 0.005) {
-    dUyellow = QString("bgcolor='#ffec99'");
+  if (qAbs(listf_data.dU.toDouble()) > 0.005) {
+    dUyellow = QString("bgcolor=#ffec99");
+  }
+  int repeat = 12;
+  if (listf_data.cycle.toInt() < ls_cycles) {
+    int progress;
+    progress = int((listf_data.cycle.toFloat() / ls_cycles)*10);
+    progressbar = QString("<td bgcolor=#69CB3F >%1</td>").arg(QString("&nbsp;").repeated(repeat)).repeated(progress)
+                  +QString("<td bgcolor=#D0D0D0 >%1</td>").arg(QString("&nbsp;").repeated(repeat)).repeated(10-progress);
+    cycleText = QString("<tr><td> <b>Cycle %1 of %2</b> </td></tr>")
+        .arg(listf_data.cycle) // 1
+        .arg(ls_cycles)        // 2
+        ;
+  } else {
+    cycleText = QString("<tr><td> <b>Final Cycle of %1</b></td></tr>")
+        .arg(ls_cycles);       // 1
+    progressbar = QString("<td bgcolor=#69CB3F>%1</td>").arg(QString("&nbsp;").repeated(repeat)).repeated(10);
   }
   QString html_output = QString(
-          "<H3>Running SHELXL %1</H3> "
-          "<body style=\"font-family:SansSerif; font-size:12pt;\">"
-          ""
-          "<table cellpadding=2%>"
-          "<tr><td>%2 threads on %3 processors </td></tr>"
-          "<tr><td>Using %9 data and %12 of %10 parameters</td> <td> (ratio %18) &nbsp; </td>"
-          "<td><i>R</i><sub>int</sub> = %5%, <i>R</i><sub>&sigma;</sub> = %6% </td></tr>"
-          "</table>"
-          "<table cellpadding=2% width=100% align=left>"
-          "<tr><td width=14%> <b>Cycle %8 </b>            </td></tr>"
-          "%13"
-          "%7"
-          "<tr><td align=right> <i>GooF</i> =             </td> <td> %11                </td>"
-          "    <td align=right  width=18%> Restr. <i>GooF</i> =  </td> <td> %19                </td></tr>"
-          "<tr><td align=right> Max. shift =              </td> <td %4> %14 &#8491; - %15  </td>"
-          "    <td align=right> Max. &Delta;U =           </td> <td %21> %16 - %17          </td></tr>"
-          "</table>"
-          "<table><tr><td bgcolor='#ffec99'> %20 </td></tr></table>"
-          "</body>")
-          .arg(listf_data.xlversion)            // 1
-          .arg(listf_data.threads)              // 2
-          .arg(listf_data.procs)                // 3
-          .arg(shiftyellow)                     // 4
-          .arg(listf_data.rint.toFloat()*100, 10, 'f', 2)         // 5
-          .arg(listf_data.rsigma.toFloat()*100, 10, 'f', 2)       // 6
-          .arg(wr2line)                         // 7 //wr2
-          .arg(listf_data.cycle)                // 8
-          .arg(listf_data.data)                 // 9
-          .arg(listf_data.all_parameters)       // 10
-          .arg(listf_data.curGoof)              // 11
-          .arg(listf_data.current_parameters)   // 12
-          .arg(html_final)                      // 13
-          .arg(listf_data.maxshift)             // 14
-          .arg(listf_data.maxshiftfor)          // 15
-          .arg(listf_data.dU)                   // 16
-          .arg(listf_data.dUfor)                // 17
-          .arg(listf_data.data.toFloat()/listf_data.all_parameters.toFloat(), 10, 'f', 1) // 18
-          .arg(listf_data.curRGoof)              // 19
-          .arg(listf_data.warnings.join("<br>")) // 20
-          .arg(dUyellow)                         // 21
+        "<body style=\"font-family:SansSerif; font-size:11pt;\">"
+        "<H2>Running SHELXL %1</H2> "
+        "<table cellpadding=3% align=left>"
+        "<tr><td colspan=2 align=left> <table><tr> %2 </tr></table> </td></tr>"
+        "<tr><td> %3 threads on %4 processors </td></tr>"
+        "<tr><td> Using %5 data and %6 of %7 parameters (ratio %8) &nbsp; </td>"
+        "<td><i>R</i><sub>int</sub> = %9%, <i>R</i><sub>&sigma;</sub> = %10% </td></tr>"
+        "</table>")
+      .arg(listf_data.xlversion)            // 1
+      .arg(progressbar)                     // 2
+      .arg(listf_data.threads)              // 3
+      .arg(listf_data.procs)                // 4
+      .arg(listf_data.data)                 // 5
+      .arg(listf_data.current_parameters)   // 6
+      .arg(listf_data.all_parameters)       // 7
+      .arg(listf_data.data.toDouble()/listf_data.all_parameters.toDouble(), 10, 'f', 1) // 8
+      .arg(listf_data.rint.toDouble()*100, 10, 'f', 2)     // 9
+      .arg(listf_data.rsigma.toDouble()*100, 10, 'f', 2)   // 10
       ;
+
+  QString html_output2 = QString("<table cellpadding=2%>"
+          "%1"
+          "%2"
+          "%3"
+          "<tr><td align=right> <i>GooF</i> =             </td> <td> %4                     </td>"
+          "    <td align=right  width=18%> Restr. <i>GooF</i> =  </td> <td> %5              </td></tr>"
+          "<tr><td align=right> Max. shift =              </td> <td %6> %7 &#8491; - %8     </td>"
+          "    <td align=right> Max. &Delta;U =           </td> <td %21> %9 - %10          </td></tr>"
+          "</table>"
+          "<table><tr><td bgcolor=#ffec99><b> %11 </b></td></tr></table>"
+          "</body>")
+          .arg(cycleText)                        // 1
+          .arg(html_final)                       // 2
+          .arg(wr2line)                          // 3 //wr2
+          .arg(listf_data.curGoof)               // 4
+          .arg(listf_data.curRGoof)              // 5
+          .arg(shiftyellow)                      // 6
+          .arg(listf_data.maxshift)              // 7
+          .arg(listf_data.maxshiftfor)           // 8
+          .arg(listf_data.dU)                    // 9
+          .arg(listf_data.dUfor)                 // 10
+          .arg(listf_data.warnings.join("<br>")) // 11
+      ;
+  if (!listf_data.wr2.isEmpty()) {
+    html_output += html_output2;
+  } else {
+    // In this case, no refinement happened:
+    if (!listf_data.warnings.isEmpty()) {
+      // even if no refinenemt happened, I want to display the warnings:
+      html_output += QString("<table><tr><td bgcolor=#ffec99> %2 </td></tr></table>")
+          .arg(listf_data.warnings.join("<br>"));
+    } else {
+      // no warning, but still waiting for output from SHLEXL:
+      html_output += QString("<b>Waiting for output from SHELXL...</b>");
+    }
+  }
+  if (!listf_data.time.isEmpty() && listf_data.wr2.isEmpty()) {
+    // SHELXL finished regularly (time elapsed output), but no refinement happened (wr2 is empty)
+    html_output += QString("<br><b>SHELXL failed to run! Please inspect the instructions.</b>");
+  }
   return html_output;
 }
 
@@ -629,26 +667,30 @@ QStringList XLOutputParser::xl_current_wr2_data_param(QString line) {
 QStringList XLOutputParser::xl_rint_rsigma(QString line) {
   //! Returns Rint and Rsigma of the dataset.
   //! " R(int) = 0.0504     R(sigma) = 0.0585      Friedel opposites merged"
+  //chuebsch: this crashed:
+  //Data:      19 unique,      0 suppressed   R(int) = 0.0000   R(sigma) =13.2352
+  //
   QString rint = "";
   QString rsigma = "";
   QStringList linesplit, rvals;
-  if (line.contains("R(int)") && (line.split(" ", QString::SkipEmptyParts).size() > 10) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
-    rint = linesplit.at(7);
-    rsigma = linesplit.at(10);
+  QString l=line.remove('=');
+  if (line.contains("R(sigma)")) {
+    linesplit = l.split(" ", QString::SkipEmptyParts);
+    int RintInd = linesplit.indexOf(QRegExp("R\\(int\\)"));
+    if ((RintInd != -1) && linesplit.length() > RintInd+1) {//>= leads to segmentation fault
+      rint = linesplit.at(RintInd+1);
+    }
+    int RsigInd = linesplit.indexOf(QRegExp("R\\(sigma\\)"));
+    if ((RsigInd != -1) && linesplit.length() > RsigInd+1) {//>= leads to segmentation fault
+      rsigma = linesplit.at(RsigInd+1);
+    }//else qDebug()<<linesplit<<RsigInd;
+
   }
   rvals.append(rint);
   rvals.append(rsigma);
   return rvals;
 }
 
-int XLOutputParser::xl_syst_abs_bad_equiv(QString line) {
-  //! Returns the number of bad equivalents reported by shelxl.
-  int badequiv = 3;
-  qDebug() << line;
-  return badequiv;
-}
-
 QStringList XLOutputParser::xl_current_goof(QString line) {
   //! Returns the current Goof of the refinement. This value is
   //! the last value in the continuesly growing lst file.
@@ -868,4 +910,14 @@ QStringList XLOutputParser::xl_flacksvals(QString line) {
   return values;
 }
 
-
+QString XLOutputParser::xl_timeval(QString line) {
+  //! +  pn_a          finished at 12:33:29   Total elapsed time:      0.00 secs  +
+  //! returns the elapsed time of a SHELXL run
+  QStringList linesplit;
+  QString time = "";
+  if (line.contains("finished") && line.contains("time")) {
+    linesplit = line.split(" ", QString::SkipEmptyParts);
+    time = linesplit.at(linesplit.indexOf("time:")+1);
+  }
+  return time;
+}
