@@ -173,6 +173,25 @@ double m11, m21, m31, m12, m22, m32, m13, m23, m33;
 		  a.m21, a.m22, a.m23,
 		  a.m31, a.m32, a.m33);
  }
+inline double determinant (Matrix a){
+return a.m11*a.m22*a.m33 - a.m11*a.m23*a.m32 - a.m12*a.m21*a.m33 + a.m12*a.m23*a.m31 +a.m13*a.m21*a.m32 -a.m13*a.m22*a.m31;
+}
+inline Matrix inverse (Matrix A){
+  double D = determinant(A);
+  if (D==0) return A;
+  D=1.0/D;
+  return Matrix(
+          D*(A.m22*A.m33-A.m23*A.m32),//x11
+          D*(A.m13*A.m32-A.m12*A.m33),//x21
+          D*(A.m21*A.m23-A.m13*A.m22),//x31
+          D*(A.m23*A.m31-A.m21*A.m33),//x12
+          D*(A.m11*A.m33-A.m13*A.m31),//x22
+          D*(A.m13*A.m21-A.m11*A.m23),//x32
+          D*(A.m21*A.m32-A.m22*A.m31),//x13
+          D*(A.m12*A.m31-A.m11*A.m32),//x23
+          D*(A.m11*A.m22-A.m12*A.m21)//x33
+          );
+}
  inline bool operator == (const Matrix &a,const Matrix &b){
      return ((a.m11 == b.m11)&&(a.m21 == b.m21)&&(a.m31 == b.m31)&&
      (a.m12 == b.m12)&&(a.m22 == b.m22)&&(a.m23 == b.m23)&&
@@ -207,6 +226,21 @@ inline V3 operator * (const V3 &a, const Matrix &b){
   erg.z = b.m31*a.x + b.m32*a.y + b.m33*a.z;
   return erg;
 }
+inline Matrix operator * (const Matrix &a,const double &b){
+  Matrix erg;
+  erg.m11 = a.m11*b;
+  erg.m21 = a.m21*b;
+  erg.m31 = a.m31*b;
+
+  erg.m12 = a.m12*b;
+  erg.m22 = a.m22*b;
+  erg.m32 = a.m32*b;
+
+  erg.m13 = a.m13*b;
+  erg.m23 = a.m23*b;
+  erg.m33 = a.m33*b;
+  return erg;
+}
 //! MyAtom an atom object
 typedef struct MyAtom{
   //! Label is the atom label with residue nuber seperated by '_' and the symmetry operation number seperated by french quotes.
@@ -1074,6 +1108,7 @@ struct Cell {
   double bs;
   //! the reciprocal dimension c 
   double cs;
+
   //! \f$ \tau = c ((\cos(\alpha) - \cos(\beta)  \cos(\gamma)) / \sin(\gamma))\f$
   double tau;
   //! \f$ \cos(\gamma)\f$ 
@@ -1090,6 +1125,8 @@ struct Cell {
   QList<Matrix> symmops;
   //! List of translations
   QList<V3> trans;
+  //!number of symmops without centring and inversion applyed
+  int ns0;
   //! space group is centred (A,B,C,I,F)
   bool centered;
    //! space group is centro symmetric
@@ -1098,6 +1135,7 @@ struct Cell {
   QString Z;
   //! the wavelenth  \f$ \lambda  \f$ in Angstroms
   double wave;
+  Matrix G,Gi;//metric tensor and its inverse
 };
 //! shortest distance matrix item type
 struct SdmItem{
@@ -1133,12 +1171,17 @@ QList<int> neighbors;
 class Molecule{
 public:
 	bool nopm1;//!< No part minus n ghost
-    bool highlightEquivalents;//!< Symmetry generated objects will be drawn in lighter colors if this is true
+        bool highlightEquivalents;//!< Symmetry generated objects will be drawn in lighter colors if this is true
 	bool qbeforehkl;//!< There are Q-Peaks before HKLF instruction 
         bool growQPeak;//!< Q-Peaks should be treated with symmetry operators
 	bool monoQrom;//!< Q-Peaks in a single color instead of a gradient.
        QColor mQolor;//!< the single Q-Peak color
        double  qboMin,qboMax;
+       double exti,swat,osf;
+       int hklf;
+       double hklScale,hklSigmaScale,hklOmitSig,hklOmit2th,hklShellLow,hklShellHig;
+       Matrix hklMat;
+       QString titl;
   int LOD;//!< The Level of Detail
   QGLShaderProgram *g_Program,*saveProg;//shaders with Qt
   GLuint g_program;//GL handle for shader program
@@ -1184,6 +1227,8 @@ public:
   int pseSize;//!< Font size for the PSEWidget to be stored in the settings.
   double  pmin,//!< minimum peak height of the Q-Peaks.
 	  pmax;//!< maximum peak height of the Q-Peaks.
+  double  lmin,//!< minimum a for belo.
+	  lmax;//!< maximum a for belo.
   QColor bondColor;//!< the color of the bonds in uni colored mode.
 
   QColor enviBondColor,//!< covalent color in ENVI
