@@ -40,8 +40,8 @@ SaveHistoryWidget::SaveHistoryWidget(QString filename, QWidget *parent  , Qt::Wi
   connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 /*  QLabel *usageHint = new QLabel();
   usageHint->setText("<h1>Inherit labels assigning dialog</h1> <ul><li>If you click on OK here, then atoms on the<br>"
-		  " right collumn will inherit their Labels from<br> the atoms given in the left collumn.</li>"
-		  "<li> You can change the ordering of the right<br> collumn by drag and drop of its items.</li>"
+		  " right column will inherit their Labels from<br> the atoms given in the left column.</li>"
+		  "<li> You can change the ordering of the right<br> column by drag and drop of its items.</li>"
 		  "<li> If you click on the items on the left column<br> the atoms in the structure will<br> be <em>highlighted</em>.</li>"
 		  "<li> You <em>MUST</em> assingn a new <em>ResidueNr</em> and an<br> appropriate <em>Residue Class</em> here!</ul>");
   usageHint->setStyleSheet (QString(
