@@ -1,4 +1,4 @@
-#ifndef SAVEHISTORYWIDGET_h
+#ifndef SAVEHISTORYWIDGET_H
 #define SAVEHISTORYWIDGET_H
 
 #include <QtGui>
