@@ -11,13 +11,13 @@ QStringList shxToolTips =(QStringList()<<
 "SFAC elements or \nSFAC label a1 b1 a2 b2 a3 b3 a4 b4 c f' f'' mu r wt"<<
 "DISP E f' f'' [#] mu [#]"<<
 "UNIT n1 n2 ..."<<
-"LAUE E"<<
+"LAUE E (values of f' and f\")"<<
 "REM the rest of the line is a comment"<<
 "MORE m ,sets the verbosity m=0..3"<<
 "TIME t[s]\nHas been deprecated!"<<
 "HOPE\nHas been deprecated!"<<
 "END end of input"<<
-"HKLF n"<<
+"HKLF N[0] S[1] r11...r33[1 0 0  0 1 0  0 0 1] sm[1] m[0]"<<
 "OMIT s[-2] 2Theta(lim)[180] or\nOMIT h k l"<<
 "SHEL lowres[infinite] highres[0]"<<
 "BASF scale factors"<<
