@@ -95,7 +95,8 @@ public:
   QString dirName;
   void setFocus(bool b){focusSet=b;}
   bool isFocusSet() {return focusSet;}
-
+  int firstAtomLine;
+  
 public slots:
   void qinitres();
   void about();//!<Shows the about dialog of ShelXle.
@@ -133,7 +134,7 @@ public slots:
   void deleteAllQ();//!<Deletes all Q-Peaks.
   void deleteSelectedAtoms();//!<Deletes all selected atoms.
   void dispFromWave();//!<calculates f', f" and mu for the given wavelength and inserts DISP lines for each SFAC entry.
-  void displayResiduals(XLOutputParser &lfo, QString s);
+  void displayResiduals(XLOutputParser &lfo, QString s);//!<Displays the residuals from SHELXL in a clear way
   void doMapsNow(bool b);//!<destroys maps or (re)calculates them freshly.
   int duplicates();//!<searches for identical labeled Atoms and add them to a list. 
   void editorIsVisible(bool);//!is Editor really visble
@@ -141,6 +142,7 @@ public slots:
   void expandAll();//!<Expands all contacts .
   void extraSettings();//!<A dialog to add/edit exteral programs started from ShelXle with or without arguments.
   void exportCoordinates();//!<Exports all visible atoms to an extra file. 
+  void exportFMaps();
   bool fileSave();//!<saves the editor content to the current file.
   bool fileSaveAs();//!<Saves the editor content to a specified file.
   void fillCell();//!<Uses symmetry until the unit cell box is full.
@@ -234,6 +236,7 @@ public slots:
   void setShelxlOptions();//!< sets path and command line options for ShelXl executable.
   void setShelxlPath();//!< sets path for ShelXl executable
   void setExtraPath();//!<sets path for an external program
+  void setSDMLimit();//!< max atoms in au to skip sdm calculation
   void setMonoQ(bool vis);//!<sets monochome modus for Q-Peaks to vis @param vis mochrome mode of Q-Peaks.
   void showSearch();//!< shows the search and repleace for the editor.
   void showSearch2();//!< shows the search for the list view
@@ -280,8 +283,11 @@ public slots:
   void insertDSRLine(QString dsrline, int position, QVector<int> previousLine);
   void aboutDSR(); //!<Shows the about dialog of the DSR GUI.  
   void dsrClosed();
+  void beloWriteCube();//bello braf!
+  CEnvironment lonesome(QString s,int startNummer);//!< calculates LONE objects  
   static int isacommand(QString command);
   void displayDisagreeableRestraints();
+  void defineBarray();
 protected:
   void paintEvent(QPaintEvent *event);
   void moveEvent(QMoveEvent *event);
@@ -290,11 +296,14 @@ protected:
 private:
   bool focusSet;
   int sortierWeise;
-  int cycls;
+  int wght_cycls; //!< Number of cycles during the wght refinement.
+  int ls_cycls;   //!< Number of least-squares cycles during L.S. or CGLS refinement.
+  int SDM_Limit; //!< if the number of atoms in the au exceeds this limit shortest distance is not computed automatically default 350
+  double defden(V3 pos,CEnvironment belo);
   QNetworkAccessManager *net;
   QNetworkReply *reply;
   V3 urs;
-  QString altText;
+  QString altText, fouName;
   PSEWidget *psew;  
   QSpinBox *symmIntBx;
   QSpinBox *symmXBx;
@@ -320,7 +329,7 @@ private:
   QString labelPSE,labelSuffix,nextLabel,title;
   int labelIndex;
   QLabel *nextNameL, *replacementInfo, *hintL;
-  QCheckBox *rufModeBox,*indexIncr;
+  QCheckBox *rufModeBox,*indexIncr,*ownfcf6;
   QSpinBox *resiNrSpin;
   QSpinBox *indexSpin;
   QSpinBox *partSpin;
@@ -364,7 +373,8 @@ private:
   QTextEdit *extraOutPut;
   CodeEditor *editor , *xlPutor;
   QLineEdit *search2, *search, *replace;
-  QString unitAlt,unitNeu,shelxlPath,shelxlArgs;
+  QString unitAlt, unitNeu, shelxlPath, shelxlArgs;
+  bool useMyBArray;    //! If set to true, the b-array is not automatically set by ShelXle
   QStringList extraProgramNames,extraProgramPaths,extraOptions,extraExt2;
   QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach;
   QLineEdit *extraPath,*extraName,*extraAltExtEdit,*extraArgumentsEdit,*shxPath,*shxOptions;
@@ -474,7 +484,7 @@ private:
   bool ediVis,oupVis,startFused;
   Calculator *calcmenu;
   DSRGui *dsr;
-  int firstAtomLine;
+
 signals:
   void fileLoaded(void);
 
